// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SXTAB_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SXTAB_T32_H_

const byte kInstruction_sxtab_al_r12_r9_r11[] = {
  0x49, 0xfa, 0x8b, 0xfc // sxtab al r12 r9 r11
};
const byte kInstruction_sxtab_al_r3_r4_r10[] = {
  0x44, 0xfa, 0x8a, 0xf3 // sxtab al r3 r4 r10
};
const byte kInstruction_sxtab_al_r2_r0_r12[] = {
  0x40, 0xfa, 0x8c, 0xf2 // sxtab al r2 r0 r12
};
const byte kInstruction_sxtab_al_r9_r9_r13[] = {
  0x49, 0xfa, 0x8d, 0xf9 // sxtab al r9 r9 r13
};
const byte kInstruction_sxtab_al_r11_r2_r4[] = {
  0x42, 0xfa, 0x84, 0xfb // sxtab al r11 r2 r4
};
const byte kInstruction_sxtab_al_r7_r3_r7[] = {
  0x43, 0xfa, 0x87, 0xf7 // sxtab al r7 r3 r7
};
const byte kInstruction_sxtab_al_r11_r6_r9[] = {
  0x46, 0xfa, 0x89, 0xfb // sxtab al r11 r6 r9
};
const byte kInstruction_sxtab_al_r8_r7_r11[] = {
  0x47, 0xfa, 0x8b, 0xf8 // sxtab al r8 r7 r11
};
const byte kInstruction_sxtab_al_r14_r12_r14[] = {
  0x4c, 0xfa, 0x8e, 0xfe // sxtab al r14 r12 r14
};
const byte kInstruction_sxtab_al_r8_r5_r8[] = {
  0x45, 0xfa, 0x88, 0xf8 // sxtab al r8 r5 r8
};
const byte kInstruction_sxtab_al_r4_r4_r2[] = {
  0x44, 0xfa, 0x82, 0xf4 // sxtab al r4 r4 r2
};
const byte kInstruction_sxtab_al_r10_r6_r7[] = {
  0x46, 0xfa, 0x87, 0xfa // sxtab al r10 r6 r7
};
const byte kInstruction_sxtab_al_r9_r13_r7[] = {
  0x4d, 0xfa, 0x87, 0xf9 // sxtab al r9 r13 r7
};
const byte kInstruction_sxtab_al_r6_r8_r5[] = {
  0x48, 0xfa, 0x85, 0xf6 // sxtab al r6 r8 r5
};
const byte kInstruction_sxtab_al_r5_r10_r6[] = {
  0x4a, 0xfa, 0x86, 0xf5 // sxtab al r5 r10 r6
};
const byte kInstruction_sxtab_al_r14_r7_r11[] = {
  0x47, 0xfa, 0x8b, 0xfe // sxtab al r14 r7 r11
};
const byte kInstruction_sxtab_al_r11_r4_r14[] = {
  0x44, 0xfa, 0x8e, 0xfb // sxtab al r11 r4 r14
};
const byte kInstruction_sxtab_al_r5_r6_r4[] = {
  0x46, 0xfa, 0x84, 0xf5 // sxtab al r5 r6 r4
};
const byte kInstruction_sxtab_al_r4_r9_r0[] = {
  0x49, 0xfa, 0x80, 0xf4 // sxtab al r4 r9 r0
};
const byte kInstruction_sxtab_al_r5_r0_r8[] = {
  0x40, 0xfa, 0x88, 0xf5 // sxtab al r5 r0 r8
};
const byte kInstruction_sxtab_al_r6_r2_r10[] = {
  0x42, 0xfa, 0x8a, 0xf6 // sxtab al r6 r2 r10
};
const byte kInstruction_sxtab_al_r0_r11_r14[] = {
  0x4b, 0xfa, 0x8e, 0xf0 // sxtab al r0 r11 r14
};
const byte kInstruction_sxtab_al_r3_r10_r1[] = {
  0x4a, 0xfa, 0x81, 0xf3 // sxtab al r3 r10 r1
};
const byte kInstruction_sxtab_al_r13_r7_r8[] = {
  0x47, 0xfa, 0x88, 0xfd // sxtab al r13 r7 r8
};
const byte kInstruction_sxtab_al_r12_r5_r2[] = {
  0x45, 0xfa, 0x82, 0xfc // sxtab al r12 r5 r2
};
const byte kInstruction_sxtab_al_r7_r14_r7[] = {
  0x4e, 0xfa, 0x87, 0xf7 // sxtab al r7 r14 r7
};
const byte kInstruction_sxtab_al_r6_r6_r10[] = {
  0x46, 0xfa, 0x8a, 0xf6 // sxtab al r6 r6 r10
};
const byte kInstruction_sxtab_al_r2_r0_r2[] = {
  0x40, 0xfa, 0x82, 0xf2 // sxtab al r2 r0 r2
};
const byte kInstruction_sxtab_al_r8_r14_r11[] = {
  0x4e, 0xfa, 0x8b, 0xf8 // sxtab al r8 r14 r11
};
const byte kInstruction_sxtab_al_r10_r14_r2[] = {
  0x4e, 0xfa, 0x82, 0xfa // sxtab al r10 r14 r2
};
const byte kInstruction_sxtab_al_r14_r11_r6[] = {
  0x4b, 0xfa, 0x86, 0xfe // sxtab al r14 r11 r6
};
const byte kInstruction_sxtab_al_r9_r2_r11[] = {
  0x42, 0xfa, 0x8b, 0xf9 // sxtab al r9 r2 r11
};
const byte kInstruction_sxtab_al_r9_r9_r10[] = {
  0x49, 0xfa, 0x8a, 0xf9 // sxtab al r9 r9 r10
};
const byte kInstruction_sxtab_al_r11_r9_r13[] = {
  0x49, 0xfa, 0x8d, 0xfb // sxtab al r11 r9 r13
};
const byte kInstruction_sxtab_al_r14_r12_r7[] = {
  0x4c, 0xfa, 0x87, 0xfe // sxtab al r14 r12 r7
};
const byte kInstruction_sxtab_al_r9_r4_r7[] = {
  0x44, 0xfa, 0x87, 0xf9 // sxtab al r9 r4 r7
};
const byte kInstruction_sxtab_al_r0_r7_r8[] = {
  0x47, 0xfa, 0x88, 0xf0 // sxtab al r0 r7 r8
};
const byte kInstruction_sxtab_al_r12_r4_r4[] = {
  0x44, 0xfa, 0x84, 0xfc // sxtab al r12 r4 r4
};
const byte kInstruction_sxtab_al_r7_r9_r7[] = {
  0x49, 0xfa, 0x87, 0xf7 // sxtab al r7 r9 r7
};
const byte kInstruction_sxtab_al_r1_r13_r13[] = {
  0x4d, 0xfa, 0x8d, 0xf1 // sxtab al r1 r13 r13
};
const byte kInstruction_sxtab_al_r13_r11_r11[] = {
  0x4b, 0xfa, 0x8b, 0xfd // sxtab al r13 r11 r11
};
const byte kInstruction_sxtab_al_r0_r0_r7[] = {
  0x40, 0xfa, 0x87, 0xf0 // sxtab al r0 r0 r7
};
const byte kInstruction_sxtab_al_r2_r12_r1[] = {
  0x4c, 0xfa, 0x81, 0xf2 // sxtab al r2 r12 r1
};
const byte kInstruction_sxtab_al_r8_r2_r5[] = {
  0x42, 0xfa, 0x85, 0xf8 // sxtab al r8 r2 r5
};
const byte kInstruction_sxtab_al_r6_r0_r1[] = {
  0x40, 0xfa, 0x81, 0xf6 // sxtab al r6 r0 r1
};
const byte kInstruction_sxtab_al_r9_r13_r0[] = {
  0x4d, 0xfa, 0x80, 0xf9 // sxtab al r9 r13 r0
};
const byte kInstruction_sxtab_al_r12_r5_r1[] = {
  0x45, 0xfa, 0x81, 0xfc // sxtab al r12 r5 r1
};
const byte kInstruction_sxtab_al_r14_r3_r4[] = {
  0x43, 0xfa, 0x84, 0xfe // sxtab al r14 r3 r4
};
const byte kInstruction_sxtab_al_r5_r9_r2[] = {
  0x49, 0xfa, 0x82, 0xf5 // sxtab al r5 r9 r2
};
const byte kInstruction_sxtab_al_r8_r9_r10[] = {
  0x49, 0xfa, 0x8a, 0xf8 // sxtab al r8 r9 r10
};
const byte kInstruction_sxtab_al_r0_r11_r12[] = {
  0x4b, 0xfa, 0x8c, 0xf0 // sxtab al r0 r11 r12
};
const byte kInstruction_sxtab_al_r2_r8_r4[] = {
  0x48, 0xfa, 0x84, 0xf2 // sxtab al r2 r8 r4
};
const byte kInstruction_sxtab_al_r13_r6_r9[] = {
  0x46, 0xfa, 0x89, 0xfd // sxtab al r13 r6 r9
};
const byte kInstruction_sxtab_al_r2_r12_r9[] = {
  0x4c, 0xfa, 0x89, 0xf2 // sxtab al r2 r12 r9
};
const byte kInstruction_sxtab_al_r12_r0_r3[] = {
  0x40, 0xfa, 0x83, 0xfc // sxtab al r12 r0 r3
};
const byte kInstruction_sxtab_al_r13_r1_r1[] = {
  0x41, 0xfa, 0x81, 0xfd // sxtab al r13 r1 r1
};
const byte kInstruction_sxtab_al_r14_r6_r7[] = {
  0x46, 0xfa, 0x87, 0xfe // sxtab al r14 r6 r7
};
const byte kInstruction_sxtab_al_r8_r6_r6[] = {
  0x46, 0xfa, 0x86, 0xf8 // sxtab al r8 r6 r6
};
const byte kInstruction_sxtab_al_r14_r9_r11[] = {
  0x49, 0xfa, 0x8b, 0xfe // sxtab al r14 r9 r11
};
const byte kInstruction_sxtab_al_r6_r3_r3[] = {
  0x43, 0xfa, 0x83, 0xf6 // sxtab al r6 r3 r3
};
const byte kInstruction_sxtab_al_r6_r8_r14[] = {
  0x48, 0xfa, 0x8e, 0xf6 // sxtab al r6 r8 r14
};
const byte kInstruction_sxtab_al_r8_r3_r6[] = {
  0x43, 0xfa, 0x86, 0xf8 // sxtab al r8 r3 r6
};
const byte kInstruction_sxtab_al_r12_r6_r11[] = {
  0x46, 0xfa, 0x8b, 0xfc // sxtab al r12 r6 r11
};
const byte kInstruction_sxtab_al_r5_r8_r14[] = {
  0x48, 0xfa, 0x8e, 0xf5 // sxtab al r5 r8 r14
};
const byte kInstruction_sxtab_al_r4_r10_r8[] = {
  0x4a, 0xfa, 0x88, 0xf4 // sxtab al r4 r10 r8
};
const byte kInstruction_sxtab_al_r4_r12_r14[] = {
  0x4c, 0xfa, 0x8e, 0xf4 // sxtab al r4 r12 r14
};
const byte kInstruction_sxtab_al_r14_r8_r10[] = {
  0x48, 0xfa, 0x8a, 0xfe // sxtab al r14 r8 r10
};
const byte kInstruction_sxtab_al_r2_r10_r8[] = {
  0x4a, 0xfa, 0x88, 0xf2 // sxtab al r2 r10 r8
};
const byte kInstruction_sxtab_al_r0_r14_r7[] = {
  0x4e, 0xfa, 0x87, 0xf0 // sxtab al r0 r14 r7
};
const byte kInstruction_sxtab_al_r9_r13_r9[] = {
  0x4d, 0xfa, 0x89, 0xf9 // sxtab al r9 r13 r9
};
const byte kInstruction_sxtab_al_r7_r0_r14[] = {
  0x40, 0xfa, 0x8e, 0xf7 // sxtab al r7 r0 r14
};
const byte kInstruction_sxtab_al_r14_r4_r9[] = {
  0x44, 0xfa, 0x89, 0xfe // sxtab al r14 r4 r9
};
const byte kInstruction_sxtab_al_r1_r1_r11[] = {
  0x41, 0xfa, 0x8b, 0xf1 // sxtab al r1 r1 r11
};
const byte kInstruction_sxtab_al_r11_r6_r1[] = {
  0x46, 0xfa, 0x81, 0xfb // sxtab al r11 r6 r1
};
const byte kInstruction_sxtab_al_r2_r8_r2[] = {
  0x48, 0xfa, 0x82, 0xf2 // sxtab al r2 r8 r2
};
const byte kInstruction_sxtab_al_r1_r8_r4[] = {
  0x48, 0xfa, 0x84, 0xf1 // sxtab al r1 r8 r4
};
const byte kInstruction_sxtab_al_r2_r3_r3[] = {
  0x43, 0xfa, 0x83, 0xf2 // sxtab al r2 r3 r3
};
const byte kInstruction_sxtab_al_r4_r8_r8[] = {
  0x48, 0xfa, 0x88, 0xf4 // sxtab al r4 r8 r8
};
const byte kInstruction_sxtab_al_r6_r4_r1[] = {
  0x44, 0xfa, 0x81, 0xf6 // sxtab al r6 r4 r1
};
const byte kInstruction_sxtab_al_r1_r10_r3[] = {
  0x4a, 0xfa, 0x83, 0xf1 // sxtab al r1 r10 r3
};
const byte kInstruction_sxtab_al_r11_r14_r8[] = {
  0x4e, 0xfa, 0x88, 0xfb // sxtab al r11 r14 r8
};
const byte kInstruction_sxtab_al_r1_r6_r3[] = {
  0x46, 0xfa, 0x83, 0xf1 // sxtab al r1 r6 r3
};
const byte kInstruction_sxtab_al_r3_r13_r10[] = {
  0x4d, 0xfa, 0x8a, 0xf3 // sxtab al r3 r13 r10
};
const byte kInstruction_sxtab_al_r6_r13_r8[] = {
  0x4d, 0xfa, 0x88, 0xf6 // sxtab al r6 r13 r8
};
const byte kInstruction_sxtab_al_r12_r3_r13[] = {
  0x43, 0xfa, 0x8d, 0xfc // sxtab al r12 r3 r13
};
const byte kInstruction_sxtab_al_r8_r2_r4[] = {
  0x42, 0xfa, 0x84, 0xf8 // sxtab al r8 r2 r4
};
const byte kInstruction_sxtab_al_r10_r1_r7[] = {
  0x41, 0xfa, 0x87, 0xfa // sxtab al r10 r1 r7
};
const byte kInstruction_sxtab_al_r11_r7_r12[] = {
  0x47, 0xfa, 0x8c, 0xfb // sxtab al r11 r7 r12
};
const byte kInstruction_sxtab_al_r4_r4_r7[] = {
  0x44, 0xfa, 0x87, 0xf4 // sxtab al r4 r4 r7
};
const byte kInstruction_sxtab_al_r1_r7_r9[] = {
  0x47, 0xfa, 0x89, 0xf1 // sxtab al r1 r7 r9
};
const byte kInstruction_sxtab_al_r14_r3_r0[] = {
  0x43, 0xfa, 0x80, 0xfe // sxtab al r14 r3 r0
};
const byte kInstruction_sxtab_al_r10_r4_r7[] = {
  0x44, 0xfa, 0x87, 0xfa // sxtab al r10 r4 r7
};
const byte kInstruction_sxtab_al_r4_r9_r11[] = {
  0x49, 0xfa, 0x8b, 0xf4 // sxtab al r4 r9 r11
};
const byte kInstruction_sxtab_al_r2_r2_r0[] = {
  0x42, 0xfa, 0x80, 0xf2 // sxtab al r2 r2 r0
};
const byte kInstruction_sxtab_al_r1_r6_r12[] = {
  0x46, 0xfa, 0x8c, 0xf1 // sxtab al r1 r6 r12
};
const byte kInstruction_sxtab_al_r0_r5_r6[] = {
  0x45, 0xfa, 0x86, 0xf0 // sxtab al r0 r5 r6
};
const byte kInstruction_sxtab_al_r8_r11_r10[] = {
  0x4b, 0xfa, 0x8a, 0xf8 // sxtab al r8 r11 r10
};
const byte kInstruction_sxtab_al_r10_r4_r3[] = {
  0x44, 0xfa, 0x83, 0xfa // sxtab al r10 r4 r3
};
const byte kInstruction_sxtab_al_r1_r0_r3[] = {
  0x40, 0xfa, 0x83, 0xf1 // sxtab al r1 r0 r3
};
const byte kInstruction_sxtab_al_r11_r8_r6[] = {
  0x48, 0xfa, 0x86, 0xfb // sxtab al r11 r8 r6
};
const byte kInstruction_sxtab_al_r8_r9_r0[] = {
  0x49, 0xfa, 0x80, 0xf8 // sxtab al r8 r9 r0
};
const byte kInstruction_sxtab_al_r5_r8_r7[] = {
  0x48, 0xfa, 0x87, 0xf5 // sxtab al r5 r8 r7
};
const byte kInstruction_sxtab_al_r9_r4_r1[] = {
  0x44, 0xfa, 0x81, 0xf9 // sxtab al r9 r4 r1
};
const byte kInstruction_sxtab_al_r1_r11_r12[] = {
  0x4b, 0xfa, 0x8c, 0xf1 // sxtab al r1 r11 r12
};
const byte kInstruction_sxtab_al_r5_r5_r11[] = {
  0x45, 0xfa, 0x8b, 0xf5 // sxtab al r5 r5 r11
};
const byte kInstruction_sxtab_al_r4_r6_r13[] = {
  0x46, 0xfa, 0x8d, 0xf4 // sxtab al r4 r6 r13
};
const byte kInstruction_sxtab_al_r14_r1_r11[] = {
  0x41, 0xfa, 0x8b, 0xfe // sxtab al r14 r1 r11
};
const byte kInstruction_sxtab_al_r11_r0_r12[] = {
  0x40, 0xfa, 0x8c, 0xfb // sxtab al r11 r0 r12
};
const byte kInstruction_sxtab_al_r9_r2_r0[] = {
  0x42, 0xfa, 0x80, 0xf9 // sxtab al r9 r2 r0
};
const byte kInstruction_sxtab_al_r11_r5_r10[] = {
  0x45, 0xfa, 0x8a, 0xfb // sxtab al r11 r5 r10
};
const byte kInstruction_sxtab_al_r1_r11_r2[] = {
  0x4b, 0xfa, 0x82, 0xf1 // sxtab al r1 r11 r2
};
const byte kInstruction_sxtab_al_r14_r2_r9[] = {
  0x42, 0xfa, 0x89, 0xfe // sxtab al r14 r2 r9
};
const byte kInstruction_sxtab_al_r4_r10_r3[] = {
  0x4a, 0xfa, 0x83, 0xf4 // sxtab al r4 r10 r3
};
const byte kInstruction_sxtab_al_r1_r5_r11[] = {
  0x45, 0xfa, 0x8b, 0xf1 // sxtab al r1 r5 r11
};
const byte kInstruction_sxtab_al_r3_r10_r4[] = {
  0x4a, 0xfa, 0x84, 0xf3 // sxtab al r3 r10 r4
};
const byte kInstruction_sxtab_al_r1_r7_r10[] = {
  0x47, 0xfa, 0x8a, 0xf1 // sxtab al r1 r7 r10
};
const byte kInstruction_sxtab_al_r14_r8_r14[] = {
  0x48, 0xfa, 0x8e, 0xfe // sxtab al r14 r8 r14
};
const byte kInstruction_sxtab_al_r12_r11_r4[] = {
  0x4b, 0xfa, 0x84, 0xfc // sxtab al r12 r11 r4
};
const byte kInstruction_sxtab_al_r7_r9_r6[] = {
  0x49, 0xfa, 0x86, 0xf7 // sxtab al r7 r9 r6
};
const byte kInstruction_sxtab_al_r8_r8_r9[] = {
  0x48, 0xfa, 0x89, 0xf8 // sxtab al r8 r8 r9
};
const byte kInstruction_sxtab_al_r12_r5_r0[] = {
  0x45, 0xfa, 0x80, 0xfc // sxtab al r12 r5 r0
};
const byte kInstruction_sxtab_al_r6_r11_r12[] = {
  0x4b, 0xfa, 0x8c, 0xf6 // sxtab al r6 r11 r12
};
const byte kInstruction_sxtab_al_r9_r5_r11[] = {
  0x45, 0xfa, 0x8b, 0xf9 // sxtab al r9 r5 r11
};
const byte kInstruction_sxtab_al_r6_r14_r6[] = {
  0x4e, 0xfa, 0x86, 0xf6 // sxtab al r6 r14 r6
};
const byte kInstruction_sxtab_al_r0_r3_r7[] = {
  0x43, 0xfa, 0x87, 0xf0 // sxtab al r0 r3 r7
};
const byte kInstruction_sxtab_al_r9_r5_r10[] = {
  0x45, 0xfa, 0x8a, 0xf9 // sxtab al r9 r5 r10
};
const byte kInstruction_sxtab_al_r4_r1_r6[] = {
  0x41, 0xfa, 0x86, 0xf4 // sxtab al r4 r1 r6
};
const byte kInstruction_sxtab_al_r6_r1_r13[] = {
  0x41, 0xfa, 0x8d, 0xf6 // sxtab al r6 r1 r13
};
const byte kInstruction_sxtab_al_r13_r1_r4[] = {
  0x41, 0xfa, 0x84, 0xfd // sxtab al r13 r1 r4
};
const byte kInstruction_sxtab_al_r10_r11_r9[] = {
  0x4b, 0xfa, 0x89, 0xfa // sxtab al r10 r11 r9
};
const byte kInstruction_sxtab_al_r14_r13_r7[] = {
  0x4d, 0xfa, 0x87, 0xfe // sxtab al r14 r13 r7
};
const byte kInstruction_sxtab_al_r5_r3_r13[] = {
  0x43, 0xfa, 0x8d, 0xf5 // sxtab al r5 r3 r13
};
const byte kInstruction_sxtab_al_r8_r9_r6[] = {
  0x49, 0xfa, 0x86, 0xf8 // sxtab al r8 r9 r6
};
const byte kInstruction_sxtab_al_r9_r10_r5[] = {
  0x4a, 0xfa, 0x85, 0xf9 // sxtab al r9 r10 r5
};
const byte kInstruction_sxtab_al_r12_r11_r7[] = {
  0x4b, 0xfa, 0x87, 0xfc // sxtab al r12 r11 r7
};
const byte kInstruction_sxtab_al_r5_r13_r12[] = {
  0x4d, 0xfa, 0x8c, 0xf5 // sxtab al r5 r13 r12
};
const byte kInstruction_sxtab_al_r9_r13_r8[] = {
  0x4d, 0xfa, 0x88, 0xf9 // sxtab al r9 r13 r8
};
const byte kInstruction_sxtab_al_r5_r3_r9[] = {
  0x43, 0xfa, 0x89, 0xf5 // sxtab al r5 r3 r9
};
const byte kInstruction_sxtab_al_r8_r5_r14[] = {
  0x45, 0xfa, 0x8e, 0xf8 // sxtab al r8 r5 r14
};
const byte kInstruction_sxtab_al_r8_r10_r10[] = {
  0x4a, 0xfa, 0x8a, 0xf8 // sxtab al r8 r10 r10
};
const byte kInstruction_sxtab_al_r2_r6_r4[] = {
  0x46, 0xfa, 0x84, 0xf2 // sxtab al r2 r6 r4
};
const byte kInstruction_sxtab_al_r10_r7_r1[] = {
  0x47, 0xfa, 0x81, 0xfa // sxtab al r10 r7 r1
};
const byte kInstruction_sxtab_al_r4_r0_r5[] = {
  0x40, 0xfa, 0x85, 0xf4 // sxtab al r4 r0 r5
};
const byte kInstruction_sxtab_al_r7_r12_r9[] = {
  0x4c, 0xfa, 0x89, 0xf7 // sxtab al r7 r12 r9
};
const byte kInstruction_sxtab_al_r11_r11_r10[] = {
  0x4b, 0xfa, 0x8a, 0xfb // sxtab al r11 r11 r10
};
const byte kInstruction_sxtab_al_r3_r9_r13[] = {
  0x49, 0xfa, 0x8d, 0xf3 // sxtab al r3 r9 r13
};
const byte kInstruction_sxtab_al_r10_r4_r4[] = {
  0x44, 0xfa, 0x84, 0xfa // sxtab al r10 r4 r4
};
const byte kInstruction_sxtab_al_r13_r1_r11[] = {
  0x41, 0xfa, 0x8b, 0xfd // sxtab al r13 r1 r11
};
const byte kInstruction_sxtab_al_r2_r13_r0[] = {
  0x4d, 0xfa, 0x80, 0xf2 // sxtab al r2 r13 r0
};
const byte kInstruction_sxtab_al_r11_r4_r1[] = {
  0x44, 0xfa, 0x81, 0xfb // sxtab al r11 r4 r1
};
const byte kInstruction_sxtab_al_r1_r3_r10[] = {
  0x43, 0xfa, 0x8a, 0xf1 // sxtab al r1 r3 r10
};
const byte kInstruction_sxtab_al_r4_r13_r2[] = {
  0x4d, 0xfa, 0x82, 0xf4 // sxtab al r4 r13 r2
};
const byte kInstruction_sxtab_al_r4_r8_r0[] = {
  0x48, 0xfa, 0x80, 0xf4 // sxtab al r4 r8 r0
};
const byte kInstruction_sxtab_al_r9_r6_r1[] = {
  0x46, 0xfa, 0x81, 0xf9 // sxtab al r9 r6 r1
};
const byte kInstruction_sxtab_al_r14_r14_r10[] = {
  0x4e, 0xfa, 0x8a, 0xfe // sxtab al r14 r14 r10
};
const byte kInstruction_sxtab_al_r9_r9_r2[] = {
  0x49, 0xfa, 0x82, 0xf9 // sxtab al r9 r9 r2
};
const byte kInstruction_sxtab_al_r14_r3_r12[] = {
  0x43, 0xfa, 0x8c, 0xfe // sxtab al r14 r3 r12
};
const byte kInstruction_sxtab_al_r9_r4_r0[] = {
  0x44, 0xfa, 0x80, 0xf9 // sxtab al r9 r4 r0
};
const byte kInstruction_sxtab_al_r10_r10_r11[] = {
  0x4a, 0xfa, 0x8b, 0xfa // sxtab al r10 r10 r11
};
const byte kInstruction_sxtab_al_r0_r1_r13[] = {
  0x41, 0xfa, 0x8d, 0xf0 // sxtab al r0 r1 r13
};
const byte kInstruction_sxtab_al_r10_r8_r13[] = {
  0x48, 0xfa, 0x8d, 0xfa // sxtab al r10 r8 r13
};
const byte kInstruction_sxtab_al_r8_r0_r2[] = {
  0x40, 0xfa, 0x82, 0xf8 // sxtab al r8 r0 r2
};
const byte kInstruction_sxtab_al_r2_r0_r7[] = {
  0x40, 0xfa, 0x87, 0xf2 // sxtab al r2 r0 r7
};
const byte kInstruction_sxtab_al_r11_r12_r10[] = {
  0x4c, 0xfa, 0x8a, 0xfb // sxtab al r11 r12 r10
};
const byte kInstruction_sxtab_al_r0_r5_r3[] = {
  0x45, 0xfa, 0x83, 0xf0 // sxtab al r0 r5 r3
};
const byte kInstruction_sxtab_al_r3_r2_r0[] = {
  0x42, 0xfa, 0x80, 0xf3 // sxtab al r3 r2 r0
};
const byte kInstruction_sxtab_al_r12_r10_r1[] = {
  0x4a, 0xfa, 0x81, 0xfc // sxtab al r12 r10 r1
};
const byte kInstruction_sxtab_al_r3_r2_r14[] = {
  0x42, 0xfa, 0x8e, 0xf3 // sxtab al r3 r2 r14
};
const byte kInstruction_sxtab_al_r4_r12_r1[] = {
  0x4c, 0xfa, 0x81, 0xf4 // sxtab al r4 r12 r1
};
const byte kInstruction_sxtab_al_r14_r8_r3[] = {
  0x48, 0xfa, 0x83, 0xfe // sxtab al r14 r8 r3
};
const byte kInstruction_sxtab_al_r4_r14_r12[] = {
  0x4e, 0xfa, 0x8c, 0xf4 // sxtab al r4 r14 r12
};
const byte kInstruction_sxtab_al_r3_r3_r4[] = {
  0x43, 0xfa, 0x84, 0xf3 // sxtab al r3 r3 r4
};
const byte kInstruction_sxtab_al_r10_r13_r4[] = {
  0x4d, 0xfa, 0x84, 0xfa // sxtab al r10 r13 r4
};
const byte kInstruction_sxtab_al_r9_r2_r12[] = {
  0x42, 0xfa, 0x8c, 0xf9 // sxtab al r9 r2 r12
};
const byte kInstruction_sxtab_al_r5_r13_r7[] = {
  0x4d, 0xfa, 0x87, 0xf5 // sxtab al r5 r13 r7
};
const byte kInstruction_sxtab_al_r13_r12_r9[] = {
  0x4c, 0xfa, 0x89, 0xfd // sxtab al r13 r12 r9
};
const byte kInstruction_sxtab_al_r4_r4_r5[] = {
  0x44, 0xfa, 0x85, 0xf4 // sxtab al r4 r4 r5
};
const byte kInstruction_sxtab_al_r1_r8_r12[] = {
  0x48, 0xfa, 0x8c, 0xf1 // sxtab al r1 r8 r12
};
const byte kInstruction_sxtab_al_r1_r8_r6[] = {
  0x48, 0xfa, 0x86, 0xf1 // sxtab al r1 r8 r6
};
const byte kInstruction_sxtab_al_r14_r11_r4[] = {
  0x4b, 0xfa, 0x84, 0xfe // sxtab al r14 r11 r4
};
const byte kInstruction_sxtab_al_r14_r9_r3[] = {
  0x49, 0xfa, 0x83, 0xfe // sxtab al r14 r9 r3
};
const byte kInstruction_sxtab_al_r11_r5_r9[] = {
  0x45, 0xfa, 0x89, 0xfb // sxtab al r11 r5 r9
};
const byte kInstruction_sxtab_al_r3_r10_r10[] = {
  0x4a, 0xfa, 0x8a, 0xf3 // sxtab al r3 r10 r10
};
const byte kInstruction_sxtab_al_r6_r13_r14[] = {
  0x4d, 0xfa, 0x8e, 0xf6 // sxtab al r6 r13 r14
};
const byte kInstruction_sxtab_al_r1_r8_r14[] = {
  0x48, 0xfa, 0x8e, 0xf1 // sxtab al r1 r8 r14
};
const byte kInstruction_sxtab_al_r10_r1_r10[] = {
  0x41, 0xfa, 0x8a, 0xfa // sxtab al r10 r1 r10
};
const byte kInstruction_sxtab_al_r8_r1_r1[] = {
  0x41, 0xfa, 0x81, 0xf8 // sxtab al r8 r1 r1
};
const byte kInstruction_sxtab_al_r10_r10_r4[] = {
  0x4a, 0xfa, 0x84, 0xfa // sxtab al r10 r10 r4
};
const byte kInstruction_sxtab_al_r9_r11_r13[] = {
  0x4b, 0xfa, 0x8d, 0xf9 // sxtab al r9 r11 r13
};
const byte kInstruction_sxtab_al_r14_r8_r8[] = {
  0x48, 0xfa, 0x88, 0xfe // sxtab al r14 r8 r8
};
const byte kInstruction_sxtab_al_r13_r4_r10[] = {
  0x44, 0xfa, 0x8a, 0xfd // sxtab al r13 r4 r10
};
const byte kInstruction_sxtab_al_r14_r3_r1[] = {
  0x43, 0xfa, 0x81, 0xfe // sxtab al r14 r3 r1
};
const byte kInstruction_sxtab_al_r5_r11_r14[] = {
  0x4b, 0xfa, 0x8e, 0xf5 // sxtab al r5 r11 r14
};
const byte kInstruction_sxtab_al_r2_r6_r6[] = {
  0x46, 0xfa, 0x86, 0xf2 // sxtab al r2 r6 r6
};
const byte kInstruction_sxtab_al_r14_r1_r14[] = {
  0x41, 0xfa, 0x8e, 0xfe // sxtab al r14 r1 r14
};
const byte kInstruction_sxtab_al_r5_r10_r0[] = {
  0x4a, 0xfa, 0x80, 0xf5 // sxtab al r5 r10 r0
};
const byte kInstruction_sxtab_al_r11_r2_r5[] = {
  0x42, 0xfa, 0x85, 0xfb // sxtab al r11 r2 r5
};
const byte kInstruction_sxtab_al_r4_r9_r1[] = {
  0x49, 0xfa, 0x81, 0xf4 // sxtab al r4 r9 r1
};
const byte kInstruction_sxtab_al_r12_r7_r2[] = {
  0x47, 0xfa, 0x82, 0xfc // sxtab al r12 r7 r2
};
const byte kInstruction_sxtab_al_r10_r12_r9[] = {
  0x4c, 0xfa, 0x89, 0xfa // sxtab al r10 r12 r9
};
const byte kInstruction_sxtab_al_r2_r3_r12[] = {
  0x43, 0xfa, 0x8c, 0xf2 // sxtab al r2 r3 r12
};
const byte kInstruction_sxtab_al_r7_r6_r3[] = {
  0x46, 0xfa, 0x83, 0xf7 // sxtab al r7 r6 r3
};
const byte kInstruction_sxtab_al_r11_r11_r8[] = {
  0x4b, 0xfa, 0x88, 0xfb // sxtab al r11 r11 r8
};
const byte kInstruction_sxtab_al_r6_r14_r10[] = {
  0x4e, 0xfa, 0x8a, 0xf6 // sxtab al r6 r14 r10
};
const byte kInstruction_sxtab_al_r13_r2_r4[] = {
  0x42, 0xfa, 0x84, 0xfd // sxtab al r13 r2 r4
};
const byte kInstruction_sxtab_al_r5_r5_r4[] = {
  0x45, 0xfa, 0x84, 0xf5 // sxtab al r5 r5 r4
};
const byte kInstruction_sxtab_al_r9_r1_r2[] = {
  0x41, 0xfa, 0x82, 0xf9 // sxtab al r9 r1 r2
};
const byte kInstruction_sxtab_al_r3_r10_r14[] = {
  0x4a, 0xfa, 0x8e, 0xf3 // sxtab al r3 r10 r14
};
const byte kInstruction_sxtab_al_r1_r9_r0[] = {
  0x49, 0xfa, 0x80, 0xf1 // sxtab al r1 r9 r0
};
const byte kInstruction_sxtab_al_r4_r10_r12[] = {
  0x4a, 0xfa, 0x8c, 0xf4 // sxtab al r4 r10 r12
};
const byte kInstruction_sxtab_al_r8_r9_r2[] = {
  0x49, 0xfa, 0x82, 0xf8 // sxtab al r8 r9 r2
};
const byte kInstruction_sxtab_al_r0_r14_r0[] = {
  0x4e, 0xfa, 0x80, 0xf0 // sxtab al r0 r14 r0
};
const byte kInstruction_sxtab_al_r14_r11_r11[] = {
  0x4b, 0xfa, 0x8b, 0xfe // sxtab al r14 r11 r11
};
const byte kInstruction_sxtab_al_r9_r12_r5[] = {
  0x4c, 0xfa, 0x85, 0xf9 // sxtab al r9 r12 r5
};
const byte kInstruction_sxtab_al_r11_r8_r3[] = {
  0x48, 0xfa, 0x83, 0xfb // sxtab al r11 r8 r3
};
const byte kInstruction_sxtab_al_r13_r11_r8[] = {
  0x4b, 0xfa, 0x88, 0xfd // sxtab al r13 r11 r8
};
const byte kInstruction_sxtab_al_r4_r13_r12[] = {
  0x4d, 0xfa, 0x8c, 0xf4 // sxtab al r4 r13 r12
};
const byte kInstruction_sxtab_al_r10_r13_r6[] = {
  0x4d, 0xfa, 0x86, 0xfa // sxtab al r10 r13 r6
};
const byte kInstruction_sxtab_al_r14_r7_r13[] = {
  0x47, 0xfa, 0x8d, 0xfe // sxtab al r14 r7 r13
};
const byte kInstruction_sxtab_al_r10_r2_r12[] = {
  0x42, 0xfa, 0x8c, 0xfa // sxtab al r10 r2 r12
};
const byte kInstruction_sxtab_al_r6_r9_r4[] = {
  0x49, 0xfa, 0x84, 0xf6 // sxtab al r6 r9 r4
};
const byte kInstruction_sxtab_al_r9_r8_r2[] = {
  0x48, 0xfa, 0x82, 0xf9 // sxtab al r9 r8 r2
};
const byte kInstruction_sxtab_al_r14_r5_r5[] = {
  0x45, 0xfa, 0x85, 0xfe // sxtab al r14 r5 r5
};
const byte kInstruction_sxtab_al_r11_r14_r4[] = {
  0x4e, 0xfa, 0x84, 0xfb // sxtab al r11 r14 r4
};
const byte kInstruction_sxtab_al_r8_r0_r12[] = {
  0x40, 0xfa, 0x8c, 0xf8 // sxtab al r8 r0 r12
};
const byte kInstruction_sxtab_al_r11_r6_r5[] = {
  0x46, 0xfa, 0x85, 0xfb // sxtab al r11 r6 r5
};
const byte kInstruction_sxtab_al_r11_r13_r9[] = {
  0x4d, 0xfa, 0x89, 0xfb // sxtab al r11 r13 r9
};
const byte kInstruction_sxtab_al_r14_r2_r0[] = {
  0x42, 0xfa, 0x80, 0xfe // sxtab al r14 r2 r0
};
const byte kInstruction_sxtab_al_r7_r7_r10[] = {
  0x47, 0xfa, 0x8a, 0xf7 // sxtab al r7 r7 r10
};
const byte kInstruction_sxtab_al_r10_r12_r2[] = {
  0x4c, 0xfa, 0x82, 0xfa // sxtab al r10 r12 r2
};
const byte kInstruction_sxtab_al_r9_r10_r9[] = {
  0x4a, 0xfa, 0x89, 0xf9 // sxtab al r9 r10 r9
};
const byte kInstruction_sxtab_al_r11_r0_r9[] = {
  0x40, 0xfa, 0x89, 0xfb // sxtab al r11 r0 r9
};
const byte kInstruction_sxtab_al_r3_r5_r7[] = {
  0x45, 0xfa, 0x87, 0xf3 // sxtab al r3 r5 r7
};
const byte kInstruction_sxtab_al_r0_r8_r0[] = {
  0x48, 0xfa, 0x80, 0xf0 // sxtab al r0 r8 r0
};
const byte kInstruction_sxtab_al_r1_r11_r4[] = {
  0x4b, 0xfa, 0x84, 0xf1 // sxtab al r1 r11 r4
};
const byte kInstruction_sxtab_al_r1_r14_r3[] = {
  0x4e, 0xfa, 0x83, 0xf1 // sxtab al r1 r14 r3
};
const byte kInstruction_sxtab_al_r12_r12_r13[] = {
  0x4c, 0xfa, 0x8d, 0xfc // sxtab al r12 r12 r13
};
const byte kInstruction_sxtab_al_r14_r13_r1[] = {
  0x4d, 0xfa, 0x81, 0xfe // sxtab al r14 r13 r1
};
const byte kInstruction_sxtab_al_r8_r7_r4[] = {
  0x47, 0xfa, 0x84, 0xf8 // sxtab al r8 r7 r4
};
const byte kInstruction_sxtab_al_r13_r12_r7[] = {
  0x4c, 0xfa, 0x87, 0xfd // sxtab al r13 r12 r7
};
const byte kInstruction_sxtab_al_r5_r12_r14[] = {
  0x4c, 0xfa, 0x8e, 0xf5 // sxtab al r5 r12 r14
};
const byte kInstruction_sxtab_al_r2_r2_r14[] = {
  0x42, 0xfa, 0x8e, 0xf2 // sxtab al r2 r2 r14
};
const byte kInstruction_sxtab_al_r6_r5_r9[] = {
  0x45, 0xfa, 0x89, 0xf6 // sxtab al r6 r5 r9
};
const byte kInstruction_sxtab_al_r8_r1_r3[] = {
  0x41, 0xfa, 0x83, 0xf8 // sxtab al r8 r1 r3
};
const byte kInstruction_sxtab_al_r9_r10_r1[] = {
  0x4a, 0xfa, 0x81, 0xf9 // sxtab al r9 r10 r1
};
const byte kInstruction_sxtab_al_r0_r6_r7[] = {
  0x46, 0xfa, 0x87, 0xf0 // sxtab al r0 r6 r7
};
const byte kInstruction_sxtab_al_r13_r9_r1[] = {
  0x49, 0xfa, 0x81, 0xfd // sxtab al r13 r9 r1
};
const byte kInstruction_sxtab_al_r11_r4_r8[] = {
  0x44, 0xfa, 0x88, 0xfb // sxtab al r11 r4 r8
};
const byte kInstruction_sxtab_al_r10_r1_r5[] = {
  0x41, 0xfa, 0x85, 0xfa // sxtab al r10 r1 r5
};
const byte kInstruction_sxtab_al_r7_r4_r6[] = {
  0x44, 0xfa, 0x86, 0xf7 // sxtab al r7 r4 r6
};
const byte kInstruction_sxtab_al_r14_r3_r13[] = {
  0x43, 0xfa, 0x8d, 0xfe // sxtab al r14 r3 r13
};
const byte kInstruction_sxtab_al_r9_r0_r1[] = {
  0x40, 0xfa, 0x81, 0xf9 // sxtab al r9 r0 r1
};
const byte kInstruction_sxtab_al_r6_r10_r10[] = {
  0x4a, 0xfa, 0x8a, 0xf6 // sxtab al r6 r10 r10
};
const byte kInstruction_sxtab_al_r13_r8_r8[] = {
  0x48, 0xfa, 0x88, 0xfd // sxtab al r13 r8 r8
};
const byte kInstruction_sxtab_al_r1_r1_r2[] = {
  0x41, 0xfa, 0x82, 0xf1 // sxtab al r1 r1 r2
};
const byte kInstruction_sxtab_al_r8_r1_r9[] = {
  0x41, 0xfa, 0x89, 0xf8 // sxtab al r8 r1 r9
};
const byte kInstruction_sxtab_al_r4_r7_r5[] = {
  0x47, 0xfa, 0x85, 0xf4 // sxtab al r4 r7 r5
};
const byte kInstruction_sxtab_al_r2_r13_r1[] = {
  0x4d, 0xfa, 0x81, 0xf2 // sxtab al r2 r13 r1
};
const byte kInstruction_sxtab_al_r9_r9_r5[] = {
  0x49, 0xfa, 0x85, 0xf9 // sxtab al r9 r9 r5
};
const byte kInstruction_sxtab_al_r11_r12_r8[] = {
  0x4c, 0xfa, 0x88, 0xfb // sxtab al r11 r12 r8
};
const byte kInstruction_sxtab_al_r7_r0_r3[] = {
  0x40, 0xfa, 0x83, 0xf7 // sxtab al r7 r0 r3
};
const byte kInstruction_sxtab_al_r3_r4_r13[] = {
  0x44, 0xfa, 0x8d, 0xf3 // sxtab al r3 r4 r13
};
const byte kInstruction_sxtab_al_r7_r7_r9[] = {
  0x47, 0xfa, 0x89, 0xf7 // sxtab al r7 r7 r9
};
const byte kInstruction_sxtab_al_r2_r9_r5[] = {
  0x49, 0xfa, 0x85, 0xf2 // sxtab al r2 r9 r5
};
const byte kInstruction_sxtab_al_r13_r2_r0[] = {
  0x42, 0xfa, 0x80, 0xfd // sxtab al r13 r2 r0
};
const byte kInstruction_sxtab_al_r8_r4_r2[] = {
  0x44, 0xfa, 0x82, 0xf8 // sxtab al r8 r4 r2
};
const byte kInstruction_sxtab_al_r7_r11_r11[] = {
  0x4b, 0xfa, 0x8b, 0xf7 // sxtab al r7 r11 r11
};
const byte kInstruction_sxtab_al_r6_r1_r2[] = {
  0x41, 0xfa, 0x82, 0xf6 // sxtab al r6 r1 r2
};
const byte kInstruction_sxtab_al_r10_r5_r7[] = {
  0x45, 0xfa, 0x87, 0xfa // sxtab al r10 r5 r7
};
const byte kInstruction_sxtab_al_r8_r14_r2[] = {
  0x4e, 0xfa, 0x82, 0xf8 // sxtab al r8 r14 r2
};
const byte kInstruction_sxtab_al_r12_r13_r5[] = {
  0x4d, 0xfa, 0x85, 0xfc // sxtab al r12 r13 r5
};
const byte kInstruction_sxtab_al_r0_r4_r8[] = {
  0x44, 0xfa, 0x88, 0xf0 // sxtab al r0 r4 r8
};
const byte kInstruction_sxtab_al_r9_r11_r12[] = {
  0x4b, 0xfa, 0x8c, 0xf9 // sxtab al r9 r11 r12
};
const byte kInstruction_sxtab_al_r6_r10_r5[] = {
  0x4a, 0xfa, 0x85, 0xf6 // sxtab al r6 r10 r5
};
const byte kInstruction_sxtab_al_r8_r10_r1[] = {
  0x4a, 0xfa, 0x81, 0xf8 // sxtab al r8 r10 r1
};
const byte kInstruction_sxtab_al_r13_r12_r4[] = {
  0x4c, 0xfa, 0x84, 0xfd // sxtab al r13 r12 r4
};
const byte kInstruction_sxtab_al_r14_r2_r11[] = {
  0x42, 0xfa, 0x8b, 0xfe // sxtab al r14 r2 r11
};
const byte kInstruction_sxtab_al_r1_r10_r7[] = {
  0x4a, 0xfa, 0x87, 0xf1 // sxtab al r1 r10 r7
};
const byte kInstruction_sxtab_al_r0_r1_r9[] = {
  0x41, 0xfa, 0x89, 0xf0 // sxtab al r0 r1 r9
};
const byte kInstruction_sxtab_al_r0_r12_r11[] = {
  0x4c, 0xfa, 0x8b, 0xf0 // sxtab al r0 r12 r11
};
const byte kInstruction_sxtab_al_r0_r5_r13[] = {
  0x45, 0xfa, 0x8d, 0xf0 // sxtab al r0 r5 r13
};
const byte kInstruction_sxtab_al_r9_r8_r12[] = {
  0x48, 0xfa, 0x8c, 0xf9 // sxtab al r9 r8 r12
};
const byte kInstruction_sxtab_al_r13_r3_r14[] = {
  0x43, 0xfa, 0x8e, 0xfd // sxtab al r13 r3 r14
};
const byte kInstruction_sxtab_al_r5_r2_r10[] = {
  0x42, 0xfa, 0x8a, 0xf5 // sxtab al r5 r2 r10
};
const byte kInstruction_sxtab_al_r5_r9_r3[] = {
  0x49, 0xfa, 0x83, 0xf5 // sxtab al r5 r9 r3
};
const byte kInstruction_sxtab_al_r10_r1_r8[] = {
  0x41, 0xfa, 0x88, 0xfa // sxtab al r10 r1 r8
};
const byte kInstruction_sxtab_al_r14_r1_r9[] = {
  0x41, 0xfa, 0x89, 0xfe // sxtab al r14 r1 r9
};
const byte kInstruction_sxtab_al_r7_r13_r2[] = {
  0x4d, 0xfa, 0x82, 0xf7 // sxtab al r7 r13 r2
};
const byte kInstruction_sxtab_al_r9_r7_r8[] = {
  0x47, 0xfa, 0x88, 0xf9 // sxtab al r9 r7 r8
};
const byte kInstruction_sxtab_al_r4_r7_r13[] = {
  0x47, 0xfa, 0x8d, 0xf4 // sxtab al r4 r7 r13
};
const byte kInstruction_sxtab_al_r6_r9_r12[] = {
  0x49, 0xfa, 0x8c, 0xf6 // sxtab al r6 r9 r12
};
const byte kInstruction_sxtab_al_r14_r2_r8[] = {
  0x42, 0xfa, 0x88, 0xfe // sxtab al r14 r2 r8
};
const byte kInstruction_sxtab_al_r12_r9_r8[] = {
  0x49, 0xfa, 0x88, 0xfc // sxtab al r12 r9 r8
};
const byte kInstruction_sxtab_al_r13_r5_r8[] = {
  0x45, 0xfa, 0x88, 0xfd // sxtab al r13 r5 r8
};
const byte kInstruction_sxtab_al_r13_r11_r3[] = {
  0x4b, 0xfa, 0x83, 0xfd // sxtab al r13 r11 r3
};
const byte kInstruction_sxtab_al_r4_r1_r9[] = {
  0x41, 0xfa, 0x89, 0xf4 // sxtab al r4 r1 r9
};
const byte kInstruction_sxtab_al_r10_r11_r13[] = {
  0x4b, 0xfa, 0x8d, 0xfa // sxtab al r10 r11 r13
};
const byte kInstruction_sxtab_al_r11_r13_r5[] = {
  0x4d, 0xfa, 0x85, 0xfb // sxtab al r11 r13 r5
};
const byte kInstruction_sxtab_al_r4_r3_r13[] = {
  0x43, 0xfa, 0x8d, 0xf4 // sxtab al r4 r3 r13
};
const byte kInstruction_sxtab_al_r12_r6_r3[] = {
  0x46, 0xfa, 0x83, 0xfc // sxtab al r12 r6 r3
};
const byte kInstruction_sxtab_al_r12_r5_r3[] = {
  0x45, 0xfa, 0x83, 0xfc // sxtab al r12 r5 r3
};
const byte kInstruction_sxtab_al_r3_r7_r2[] = {
  0x47, 0xfa, 0x82, 0xf3 // sxtab al r3 r7 r2
};
const byte kInstruction_sxtab_al_r6_r9_r10[] = {
  0x49, 0xfa, 0x8a, 0xf6 // sxtab al r6 r9 r10
};
const byte kInstruction_sxtab_al_r6_r2_r1[] = {
  0x42, 0xfa, 0x81, 0xf6 // sxtab al r6 r2 r1
};
const byte kInstruction_sxtab_al_r13_r13_r1[] = {
  0x4d, 0xfa, 0x81, 0xfd // sxtab al r13 r13 r1
};
const byte kInstruction_sxtab_al_r10_r10_r12[] = {
  0x4a, 0xfa, 0x8c, 0xfa // sxtab al r10 r10 r12
};
const byte kInstruction_sxtab_al_r5_r5_r3[] = {
  0x45, 0xfa, 0x83, 0xf5 // sxtab al r5 r5 r3
};
const byte kInstruction_sxtab_al_r8_r10_r14[] = {
  0x4a, 0xfa, 0x8e, 0xf8 // sxtab al r8 r10 r14
};
const byte kInstruction_sxtab_al_r4_r12_r6[] = {
  0x4c, 0xfa, 0x86, 0xf4 // sxtab al r4 r12 r6
};
const byte kInstruction_sxtab_al_r1_r12_r5[] = {
  0x4c, 0xfa, 0x85, 0xf1 // sxtab al r1 r12 r5
};
const byte kInstruction_sxtab_al_r14_r1_r12[] = {
  0x41, 0xfa, 0x8c, 0xfe // sxtab al r14 r1 r12
};
const byte kInstruction_sxtab_al_r5_r3_r10[] = {
  0x43, 0xfa, 0x8a, 0xf5 // sxtab al r5 r3 r10
};
const byte kInstruction_sxtab_al_r6_r11_r8[] = {
  0x4b, 0xfa, 0x88, 0xf6 // sxtab al r6 r11 r8
};
const byte kInstruction_sxtab_al_r1_r5_r7[] = {
  0x45, 0xfa, 0x87, 0xf1 // sxtab al r1 r5 r7
};
const byte kInstruction_sxtab_al_r7_r14_r8[] = {
  0x4e, 0xfa, 0x88, 0xf7 // sxtab al r7 r14 r8
};
const byte kInstruction_sxtab_al_r7_r10_r11[] = {
  0x4a, 0xfa, 0x8b, 0xf7 // sxtab al r7 r10 r11
};
const byte kInstruction_sxtab_al_r0_r14_r11[] = {
  0x4e, 0xfa, 0x8b, 0xf0 // sxtab al r0 r14 r11
};
const byte kInstruction_sxtab_al_r0_r12_r5[] = {
  0x4c, 0xfa, 0x85, 0xf0 // sxtab al r0 r12 r5
};
const byte kInstruction_sxtab_al_r2_r2_r3[] = {
  0x42, 0xfa, 0x83, 0xf2 // sxtab al r2 r2 r3
};
const byte kInstruction_sxtab_al_r1_r4_r7[] = {
  0x44, 0xfa, 0x87, 0xf1 // sxtab al r1 r4 r7
};
const byte kInstruction_sxtab_al_r10_r10_r1[] = {
  0x4a, 0xfa, 0x81, 0xfa // sxtab al r10 r10 r1
};
const byte kInstruction_sxtab_al_r7_r6_r10[] = {
  0x46, 0xfa, 0x8a, 0xf7 // sxtab al r7 r6 r10
};
const byte kInstruction_sxtab_al_r10_r14_r9[] = {
  0x4e, 0xfa, 0x89, 0xfa // sxtab al r10 r14 r9
};
const byte kInstruction_sxtab_al_r11_r14_r14[] = {
  0x4e, 0xfa, 0x8e, 0xfb // sxtab al r11 r14 r14
};
const byte kInstruction_sxtab_al_r9_r13_r6[] = {
  0x4d, 0xfa, 0x86, 0xf9 // sxtab al r9 r13 r6
};
const byte kInstruction_sxtab_al_r3_r8_r13[] = {
  0x48, 0xfa, 0x8d, 0xf3 // sxtab al r3 r8 r13
};
const byte kInstruction_sxtab_al_r14_r6_r8[] = {
  0x46, 0xfa, 0x88, 0xfe // sxtab al r14 r6 r8
};
const byte kInstruction_sxtab_al_r14_r4_r4[] = {
  0x44, 0xfa, 0x84, 0xfe // sxtab al r14 r4 r4
};
const byte kInstruction_sxtab_al_r9_r5_r3[] = {
  0x45, 0xfa, 0x83, 0xf9 // sxtab al r9 r5 r3
};
const byte kInstruction_sxtab_al_r2_r4_r14[] = {
  0x44, 0xfa, 0x8e, 0xf2 // sxtab al r2 r4 r14
};
const byte kInstruction_sxtab_al_r14_r2_r12[] = {
  0x42, 0xfa, 0x8c, 0xfe // sxtab al r14 r2 r12
};
const byte kInstruction_sxtab_al_r11_r6_r2[] = {
  0x46, 0xfa, 0x82, 0xfb // sxtab al r11 r6 r2
};
const byte kInstruction_sxtab_al_r0_r9_r12[] = {
  0x49, 0xfa, 0x8c, 0xf0 // sxtab al r0 r9 r12
};
const byte kInstruction_sxtab_al_r3_r1_r14[] = {
  0x41, 0xfa, 0x8e, 0xf3 // sxtab al r3 r1 r14
};
const byte kInstruction_sxtab_al_r10_r14_r1[] = {
  0x4e, 0xfa, 0x81, 0xfa // sxtab al r10 r14 r1
};
const byte kInstruction_sxtab_al_r2_r7_r13[] = {
  0x47, 0xfa, 0x8d, 0xf2 // sxtab al r2 r7 r13
};
const byte kInstruction_sxtab_al_r11_r2_r13[] = {
  0x42, 0xfa, 0x8d, 0xfb // sxtab al r11 r2 r13
};
const byte kInstruction_sxtab_al_r4_r11_r12[] = {
  0x4b, 0xfa, 0x8c, 0xf4 // sxtab al r4 r11 r12
};
const byte kInstruction_sxtab_al_r14_r12_r0[] = {
  0x4c, 0xfa, 0x80, 0xfe // sxtab al r14 r12 r0
};
const byte kInstruction_sxtab_al_r6_r9_r8[] = {
  0x49, 0xfa, 0x88, 0xf6 // sxtab al r6 r9 r8
};
const byte kInstruction_sxtab_al_r4_r10_r11[] = {
  0x4a, 0xfa, 0x8b, 0xf4 // sxtab al r4 r10 r11
};
const byte kInstruction_sxtab_al_r1_r2_r2[] = {
  0x42, 0xfa, 0x82, 0xf1 // sxtab al r1 r2 r2
};
const byte kInstruction_sxtab_al_r1_r8_r5[] = {
  0x48, 0xfa, 0x85, 0xf1 // sxtab al r1 r8 r5
};
const byte kInstruction_sxtab_al_r14_r13_r6[] = {
  0x4d, 0xfa, 0x86, 0xfe // sxtab al r14 r13 r6
};
const byte kInstruction_sxtab_al_r5_r12_r10[] = {
  0x4c, 0xfa, 0x8a, 0xf5 // sxtab al r5 r12 r10
};
const byte kInstruction_sxtab_al_r14_r0_r9[] = {
  0x40, 0xfa, 0x89, 0xfe // sxtab al r14 r0 r9
};
const byte kInstruction_sxtab_al_r4_r6_r6[] = {
  0x46, 0xfa, 0x86, 0xf4 // sxtab al r4 r6 r6
};
const byte kInstruction_sxtab_al_r3_r7_r11[] = {
  0x47, 0xfa, 0x8b, 0xf3 // sxtab al r3 r7 r11
};
const byte kInstruction_sxtab_al_r12_r9_r2[] = {
  0x49, 0xfa, 0x82, 0xfc // sxtab al r12 r9 r2
};
const byte kInstruction_sxtab_al_r1_r1_r1[] = {
  0x41, 0xfa, 0x81, 0xf1 // sxtab al r1 r1 r1
};
const byte kInstruction_sxtab_al_r11_r5_r14[] = {
  0x45, 0xfa, 0x8e, 0xfb // sxtab al r11 r5 r14
};
const byte kInstruction_sxtab_al_r9_r4_r6[] = {
  0x44, 0xfa, 0x86, 0xf9 // sxtab al r9 r4 r6
};
const byte kInstruction_sxtab_al_r10_r11_r2[] = {
  0x4b, 0xfa, 0x82, 0xfa // sxtab al r10 r11 r2
};
const byte kInstruction_sxtab_al_r14_r6_r2[] = {
  0x46, 0xfa, 0x82, 0xfe // sxtab al r14 r6 r2
};
const byte kInstruction_sxtab_al_r9_r4_r3[] = {
  0x44, 0xfa, 0x83, 0xf9 // sxtab al r9 r4 r3
};
const byte kInstruction_sxtab_al_r3_r3_r8[] = {
  0x43, 0xfa, 0x88, 0xf3 // sxtab al r3 r3 r8
};
const byte kInstruction_sxtab_al_r14_r10_r10[] = {
  0x4a, 0xfa, 0x8a, 0xfe // sxtab al r14 r10 r10
};
const byte kInstruction_sxtab_al_r2_r11_r6[] = {
  0x4b, 0xfa, 0x86, 0xf2 // sxtab al r2 r11 r6
};
const byte kInstruction_sxtab_al_r8_r12_r0[] = {
  0x4c, 0xfa, 0x80, 0xf8 // sxtab al r8 r12 r0
};
const byte kInstruction_sxtab_al_r8_r1_r13[] = {
  0x41, 0xfa, 0x8d, 0xf8 // sxtab al r8 r1 r13
};
const byte kInstruction_sxtab_al_r10_r8_r3[] = {
  0x48, 0xfa, 0x83, 0xfa // sxtab al r10 r8 r3
};
const byte kInstruction_sxtab_al_r12_r12_r8[] = {
  0x4c, 0xfa, 0x88, 0xfc // sxtab al r12 r12 r8
};
const byte kInstruction_sxtab_al_r2_r2_r11[] = {
  0x42, 0xfa, 0x8b, 0xf2 // sxtab al r2 r2 r11
};
const byte kInstruction_sxtab_al_r8_r5_r5[] = {
  0x45, 0xfa, 0x85, 0xf8 // sxtab al r8 r5 r5
};
const byte kInstruction_sxtab_al_r3_r14_r8[] = {
  0x4e, 0xfa, 0x88, 0xf3 // sxtab al r3 r14 r8
};
const byte kInstruction_sxtab_al_r13_r10_r14[] = {
  0x4a, 0xfa, 0x8e, 0xfd // sxtab al r13 r10 r14
};
const byte kInstruction_sxtab_al_r12_r6_r8[] = {
  0x46, 0xfa, 0x88, 0xfc // sxtab al r12 r6 r8
};
const byte kInstruction_sxtab_al_r6_r2_r5[] = {
  0x42, 0xfa, 0x85, 0xf6 // sxtab al r6 r2 r5
};
const byte kInstruction_sxtab_al_r12_r8_r14[] = {
  0x48, 0xfa, 0x8e, 0xfc // sxtab al r12 r8 r14
};
const byte kInstruction_sxtab_al_r10_r6_r2[] = {
  0x46, 0xfa, 0x82, 0xfa // sxtab al r10 r6 r2
};
const byte kInstruction_sxtab_al_r2_r4_r1[] = {
  0x44, 0xfa, 0x81, 0xf2 // sxtab al r2 r4 r1
};
const byte kInstruction_sxtab_al_r4_r0_r12[] = {
  0x40, 0xfa, 0x8c, 0xf4 // sxtab al r4 r0 r12
};
const byte kInstruction_sxtab_al_r13_r7_r4[] = {
  0x47, 0xfa, 0x84, 0xfd // sxtab al r13 r7 r4
};
const byte kInstruction_sxtab_al_r14_r11_r7[] = {
  0x4b, 0xfa, 0x87, 0xfe // sxtab al r14 r11 r7
};
const byte kInstruction_sxtab_al_r4_r4_r0[] = {
  0x44, 0xfa, 0x80, 0xf4 // sxtab al r4 r4 r0
};
const byte kInstruction_sxtab_al_r1_r10_r2[] = {
  0x4a, 0xfa, 0x82, 0xf1 // sxtab al r1 r10 r2
};
const byte kInstruction_sxtab_al_r2_r4_r8[] = {
  0x44, 0xfa, 0x88, 0xf2 // sxtab al r2 r4 r8
};
const byte kInstruction_sxtab_al_r2_r2_r12[] = {
  0x42, 0xfa, 0x8c, 0xf2 // sxtab al r2 r2 r12
};
const byte kInstruction_sxtab_al_r2_r4_r5[] = {
  0x44, 0xfa, 0x85, 0xf2 // sxtab al r2 r4 r5
};
const byte kInstruction_sxtab_al_r9_r3_r12[] = {
  0x43, 0xfa, 0x8c, 0xf9 // sxtab al r9 r3 r12
};
const byte kInstruction_sxtab_al_r1_r7_r4[] = {
  0x47, 0xfa, 0x84, 0xf1 // sxtab al r1 r7 r4
};
const byte kInstruction_sxtab_al_r13_r7_r12[] = {
  0x47, 0xfa, 0x8c, 0xfd // sxtab al r13 r7 r12
};
const byte kInstruction_sxtab_al_r12_r14_r0[] = {
  0x4e, 0xfa, 0x80, 0xfc // sxtab al r12 r14 r0
};
const byte kInstruction_sxtab_al_r13_r12_r14[] = {
  0x4c, 0xfa, 0x8e, 0xfd // sxtab al r13 r12 r14
};
const byte kInstruction_sxtab_al_r9_r6_r0[] = {
  0x46, 0xfa, 0x80, 0xf9 // sxtab al r9 r6 r0
};
const byte kInstruction_sxtab_al_r1_r12_r4[] = {
  0x4c, 0xfa, 0x84, 0xf1 // sxtab al r1 r12 r4
};
const byte kInstruction_sxtab_al_r5_r8_r12[] = {
  0x48, 0xfa, 0x8c, 0xf5 // sxtab al r5 r8 r12
};
const byte kInstruction_sxtab_al_r13_r11_r9[] = {
  0x4b, 0xfa, 0x89, 0xfd // sxtab al r13 r11 r9
};
const byte kInstruction_sxtab_al_r0_r2_r7[] = {
  0x42, 0xfa, 0x87, 0xf0 // sxtab al r0 r2 r7
};
const byte kInstruction_sxtab_al_r5_r3_r7[] = {
  0x43, 0xfa, 0x87, 0xf5 // sxtab al r5 r3 r7
};
const byte kInstruction_sxtab_al_r0_r3_r12[] = {
  0x43, 0xfa, 0x8c, 0xf0 // sxtab al r0 r3 r12
};
const byte kInstruction_sxtab_al_r14_r9_r4[] = {
  0x49, 0xfa, 0x84, 0xfe // sxtab al r14 r9 r4
};
const byte kInstruction_sxtab_al_r14_r9_r0[] = {
  0x49, 0xfa, 0x80, 0xfe // sxtab al r14 r9 r0
};
const byte kInstruction_sxtab_al_r3_r8_r0[] = {
  0x48, 0xfa, 0x80, 0xf3 // sxtab al r3 r8 r0
};
const byte kInstruction_sxtab_al_r3_r5_r8[] = {
  0x45, 0xfa, 0x88, 0xf3 // sxtab al r3 r5 r8
};
const byte kInstruction_sxtab_al_r3_r1_r8[] = {
  0x41, 0xfa, 0x88, 0xf3 // sxtab al r3 r1 r8
};
const byte kInstruction_sxtab_al_r9_r2_r8[] = {
  0x42, 0xfa, 0x88, 0xf9 // sxtab al r9 r2 r8
};
const byte kInstruction_sxtab_al_r3_r13_r8[] = {
  0x4d, 0xfa, 0x88, 0xf3 // sxtab al r3 r13 r8
};
const byte kInstruction_sxtab_al_r10_r2_r4[] = {
  0x42, 0xfa, 0x84, 0xfa // sxtab al r10 r2 r4
};
const byte kInstruction_sxtab_al_r1_r5_r9[] = {
  0x45, 0xfa, 0x89, 0xf1 // sxtab al r1 r5 r9
};
const byte kInstruction_sxtab_al_r8_r12_r3[] = {
  0x4c, 0xfa, 0x83, 0xf8 // sxtab al r8 r12 r3
};
const byte kInstruction_sxtab_al_r7_r14_r2[] = {
  0x4e, 0xfa, 0x82, 0xf7 // sxtab al r7 r14 r2
};
const byte kInstruction_sxtab_al_r14_r7_r4[] = {
  0x47, 0xfa, 0x84, 0xfe // sxtab al r14 r7 r4
};
const byte kInstruction_sxtab_al_r6_r0_r6[] = {
  0x40, 0xfa, 0x86, 0xf6 // sxtab al r6 r0 r6
};
const byte kInstruction_sxtab_al_r10_r3_r9[] = {
  0x43, 0xfa, 0x89, 0xfa // sxtab al r10 r3 r9
};
const byte kInstruction_sxtab_al_r7_r9_r12[] = {
  0x49, 0xfa, 0x8c, 0xf7 // sxtab al r7 r9 r12
};
const byte kInstruction_sxtab_al_r2_r3_r4[] = {
  0x43, 0xfa, 0x84, 0xf2 // sxtab al r2 r3 r4
};
const byte kInstruction_sxtab_al_r12_r4_r3[] = {
  0x44, 0xfa, 0x83, 0xfc // sxtab al r12 r4 r3
};
const byte kInstruction_sxtab_al_r13_r11_r2[] = {
  0x4b, 0xfa, 0x82, 0xfd // sxtab al r13 r11 r2
};
const byte kInstruction_sxtab_al_r12_r7_r5[] = {
  0x47, 0xfa, 0x85, 0xfc // sxtab al r12 r7 r5
};
const byte kInstruction_sxtab_al_r12_r1_r1[] = {
  0x41, 0xfa, 0x81, 0xfc // sxtab al r12 r1 r1
};
const byte kInstruction_sxtab_al_r9_r5_r13[] = {
  0x45, 0xfa, 0x8d, 0xf9 // sxtab al r9 r5 r13
};
const byte kInstruction_sxtab_al_r6_r8_r3[] = {
  0x48, 0xfa, 0x83, 0xf6 // sxtab al r6 r8 r3
};
const byte kInstruction_sxtab_al_r10_r0_r10[] = {
  0x40, 0xfa, 0x8a, 0xfa // sxtab al r10 r0 r10
};
const byte kInstruction_sxtab_al_r4_r3_r5[] = {
  0x43, 0xfa, 0x85, 0xf4 // sxtab al r4 r3 r5
};
const byte kInstruction_sxtab_al_r10_r2_r1[] = {
  0x42, 0xfa, 0x81, 0xfa // sxtab al r10 r2 r1
};
const byte kInstruction_sxtab_al_r0_r11_r13[] = {
  0x4b, 0xfa, 0x8d, 0xf0 // sxtab al r0 r11 r13
};
const byte kInstruction_sxtab_al_r1_r0_r5[] = {
  0x40, 0xfa, 0x85, 0xf1 // sxtab al r1 r0 r5
};
const byte kInstruction_sxtab_al_r10_r10_r0[] = {
  0x4a, 0xfa, 0x80, 0xfa // sxtab al r10 r10 r0
};
const byte kInstruction_sxtab_al_r8_r9_r8[] = {
  0x49, 0xfa, 0x88, 0xf8 // sxtab al r8 r9 r8
};
const byte kInstruction_sxtab_al_r4_r9_r3[] = {
  0x49, 0xfa, 0x83, 0xf4 // sxtab al r4 r9 r3
};
const byte kInstruction_sxtab_al_r9_r4_r14[] = {
  0x44, 0xfa, 0x8e, 0xf9 // sxtab al r9 r4 r14
};
const byte kInstruction_sxtab_al_r4_r14_r3[] = {
  0x4e, 0xfa, 0x83, 0xf4 // sxtab al r4 r14 r3
};
const byte kInstruction_sxtab_al_r5_r8_r2[] = {
  0x48, 0xfa, 0x82, 0xf5 // sxtab al r5 r8 r2
};
const byte kInstruction_sxtab_al_r10_r11_r3[] = {
  0x4b, 0xfa, 0x83, 0xfa // sxtab al r10 r11 r3
};
const byte kInstruction_sxtab_al_r6_r8_r1[] = {
  0x48, 0xfa, 0x81, 0xf6 // sxtab al r6 r8 r1
};
const byte kInstruction_sxtab_al_r8_r9_r3[] = {
  0x49, 0xfa, 0x83, 0xf8 // sxtab al r8 r9 r3
};
const byte kInstruction_sxtab_al_r6_r6_r13[] = {
  0x46, 0xfa, 0x8d, 0xf6 // sxtab al r6 r6 r13
};
const byte kInstruction_sxtab_al_r7_r10_r0[] = {
  0x4a, 0xfa, 0x80, 0xf7 // sxtab al r7 r10 r0
};
const byte kInstruction_sxtab_al_r6_r14_r14[] = {
  0x4e, 0xfa, 0x8e, 0xf6 // sxtab al r6 r14 r14
};
const byte kInstruction_sxtab_al_r7_r4_r2[] = {
  0x44, 0xfa, 0x82, 0xf7 // sxtab al r7 r4 r2
};
const byte kInstruction_sxtab_al_r0_r7_r0[] = {
  0x47, 0xfa, 0x80, 0xf0 // sxtab al r0 r7 r0
};
const byte kInstruction_sxtab_al_r10_r7_r11[] = {
  0x47, 0xfa, 0x8b, 0xfa // sxtab al r10 r7 r11
};
const byte kInstruction_sxtab_al_r1_r8_r8[] = {
  0x48, 0xfa, 0x88, 0xf1 // sxtab al r1 r8 r8
};
const byte kInstruction_sxtab_al_r9_r4_r8[] = {
  0x44, 0xfa, 0x88, 0xf9 // sxtab al r9 r4 r8
};
const byte kInstruction_sxtab_al_r14_r5_r2[] = {
  0x45, 0xfa, 0x82, 0xfe // sxtab al r14 r5 r2
};
const byte kInstruction_sxtab_al_r6_r12_r2[] = {
  0x4c, 0xfa, 0x82, 0xf6 // sxtab al r6 r12 r2
};
const byte kInstruction_sxtab_al_r1_r11_r8[] = {
  0x4b, 0xfa, 0x88, 0xf1 // sxtab al r1 r11 r8
};
const byte kInstruction_sxtab_al_r6_r5_r14[] = {
  0x45, 0xfa, 0x8e, 0xf6 // sxtab al r6 r5 r14
};
const byte kInstruction_sxtab_al_r12_r1_r2[] = {
  0x41, 0xfa, 0x82, 0xfc // sxtab al r12 r1 r2
};
const byte kInstruction_sxtab_al_r8_r3_r3[] = {
  0x43, 0xfa, 0x83, 0xf8 // sxtab al r8 r3 r3
};
const byte kInstruction_sxtab_al_r13_r8_r7[] = {
  0x48, 0xfa, 0x87, 0xfd // sxtab al r13 r8 r7
};
const byte kInstruction_sxtab_al_r14_r11_r13[] = {
  0x4b, 0xfa, 0x8d, 0xfe // sxtab al r14 r11 r13
};
const byte kInstruction_sxtab_al_r1_r14_r14[] = {
  0x4e, 0xfa, 0x8e, 0xf1 // sxtab al r1 r14 r14
};
const byte kInstruction_sxtab_al_r12_r4_r0[] = {
  0x44, 0xfa, 0x80, 0xfc // sxtab al r12 r4 r0
};
const byte kInstruction_sxtab_al_r0_r2_r3[] = {
  0x42, 0xfa, 0x83, 0xf0 // sxtab al r0 r2 r3
};
const byte kInstruction_sxtab_al_r1_r5_r6[] = {
  0x45, 0xfa, 0x86, 0xf1 // sxtab al r1 r5 r6
};
const byte kInstruction_sxtab_al_r7_r6_r4[] = {
  0x46, 0xfa, 0x84, 0xf7 // sxtab al r7 r6 r4
};
const byte kInstruction_sxtab_al_r0_r9_r2[] = {
  0x49, 0xfa, 0x82, 0xf0 // sxtab al r0 r9 r2
};
const byte kInstruction_sxtab_al_r7_r3_r14[] = {
  0x43, 0xfa, 0x8e, 0xf7 // sxtab al r7 r3 r14
};
const byte kInstruction_sxtab_al_r0_r5_r11[] = {
  0x45, 0xfa, 0x8b, 0xf0 // sxtab al r0 r5 r11
};
const byte kInstruction_sxtab_al_r12_r12_r5[] = {
  0x4c, 0xfa, 0x85, 0xfc // sxtab al r12 r12 r5
};
const byte kInstruction_sxtab_al_r12_r11_r6[] = {
  0x4b, 0xfa, 0x86, 0xfc // sxtab al r12 r11 r6
};
const byte kInstruction_sxtab_al_r2_r6_r8[] = {
  0x46, 0xfa, 0x88, 0xf2 // sxtab al r2 r6 r8
};
const byte kInstruction_sxtab_al_r6_r10_r9[] = {
  0x4a, 0xfa, 0x89, 0xf6 // sxtab al r6 r10 r9
};
const byte kInstruction_sxtab_al_r2_r11_r1[] = {
  0x4b, 0xfa, 0x81, 0xf2 // sxtab al r2 r11 r1
};
const byte kInstruction_sxtab_al_r11_r2_r7[] = {
  0x42, 0xfa, 0x87, 0xfb // sxtab al r11 r2 r7
};
const byte kInstruction_sxtab_al_r7_r14_r13[] = {
  0x4e, 0xfa, 0x8d, 0xf7 // sxtab al r7 r14 r13
};
const byte kInstruction_sxtab_al_r10_r5_r10[] = {
  0x45, 0xfa, 0x8a, 0xfa // sxtab al r10 r5 r10
};
const byte kInstruction_sxtab_al_r5_r6_r1[] = {
  0x46, 0xfa, 0x81, 0xf5 // sxtab al r5 r6 r1
};
const byte kInstruction_sxtab_al_r7_r4_r1[] = {
  0x44, 0xfa, 0x81, 0xf7 // sxtab al r7 r4 r1
};
const byte kInstruction_sxtab_al_r7_r12_r0[] = {
  0x4c, 0xfa, 0x80, 0xf7 // sxtab al r7 r12 r0
};
const byte kInstruction_sxtab_al_r3_r6_r8[] = {
  0x46, 0xfa, 0x88, 0xf3 // sxtab al r3 r6 r8
};
const byte kInstruction_sxtab_al_r0_r0_r8[] = {
  0x40, 0xfa, 0x88, 0xf0 // sxtab al r0 r0 r8
};
const byte kInstruction_sxtab_al_r12_r1_r11[] = {
  0x41, 0xfa, 0x8b, 0xfc // sxtab al r12 r1 r11
};
const byte kInstruction_sxtab_al_r14_r3_r14[] = {
  0x43, 0xfa, 0x8e, 0xfe // sxtab al r14 r3 r14
};
const byte kInstruction_sxtab_al_r12_r0_r14[] = {
  0x40, 0xfa, 0x8e, 0xfc // sxtab al r12 r0 r14
};
const byte kInstruction_sxtab_al_r5_r10_r9[] = {
  0x4a, 0xfa, 0x89, 0xf5 // sxtab al r5 r10 r9
};
const byte kInstruction_sxtab_al_r3_r7_r12[] = {
  0x47, 0xfa, 0x8c, 0xf3 // sxtab al r3 r7 r12
};
const byte kInstruction_sxtab_al_r10_r8_r7[] = {
  0x48, 0xfa, 0x87, 0xfa // sxtab al r10 r8 r7
};
const byte kInstruction_sxtab_al_r8_r14_r4[] = {
  0x4e, 0xfa, 0x84, 0xf8 // sxtab al r8 r14 r4
};
const byte kInstruction_sxtab_al_r6_r7_r7[] = {
  0x47, 0xfa, 0x87, 0xf6 // sxtab al r6 r7 r7
};
const byte kInstruction_sxtab_al_r13_r2_r14[] = {
  0x42, 0xfa, 0x8e, 0xfd // sxtab al r13 r2 r14
};
const byte kInstruction_sxtab_al_r1_r11_r11[] = {
  0x4b, 0xfa, 0x8b, 0xf1 // sxtab al r1 r11 r11
};
const byte kInstruction_sxtab_al_r5_r0_r13[] = {
  0x40, 0xfa, 0x8d, 0xf5 // sxtab al r5 r0 r13
};
const byte kInstruction_sxtab_al_r7_r6_r11[] = {
  0x46, 0xfa, 0x8b, 0xf7 // sxtab al r7 r6 r11
};
const byte kInstruction_sxtab_al_r4_r1_r14[] = {
  0x41, 0xfa, 0x8e, 0xf4 // sxtab al r4 r1 r14
};
const byte kInstruction_sxtab_al_r10_r4_r9[] = {
  0x44, 0xfa, 0x89, 0xfa // sxtab al r10 r4 r9
};
const byte kInstruction_sxtab_al_r5_r6_r6[] = {
  0x46, 0xfa, 0x86, 0xf5 // sxtab al r5 r6 r6
};
const byte kInstruction_sxtab_al_r14_r8_r13[] = {
  0x48, 0xfa, 0x8d, 0xfe // sxtab al r14 r8 r13
};
const byte kInstruction_sxtab_al_r13_r1_r12[] = {
  0x41, 0xfa, 0x8c, 0xfd // sxtab al r13 r1 r12
};
const byte kInstruction_sxtab_al_r2_r7_r11[] = {
  0x47, 0xfa, 0x8b, 0xf2 // sxtab al r2 r7 r11
};
const byte kInstruction_sxtab_al_r10_r4_r12[] = {
  0x44, 0xfa, 0x8c, 0xfa // sxtab al r10 r4 r12
};
const byte kInstruction_sxtab_al_r3_r10_r12[] = {
  0x4a, 0xfa, 0x8c, 0xf3 // sxtab al r3 r10 r12
};
const byte kInstruction_sxtab_al_r0_r9_r5[] = {
  0x49, 0xfa, 0x85, 0xf0 // sxtab al r0 r9 r5
};
const byte kInstruction_sxtab_al_r8_r9_r4[] = {
  0x49, 0xfa, 0x84, 0xf8 // sxtab al r8 r9 r4
};
const byte kInstruction_sxtab_al_r11_r0_r7[] = {
  0x40, 0xfa, 0x87, 0xfb // sxtab al r11 r0 r7
};
const byte kInstruction_sxtab_al_r11_r5_r7[] = {
  0x45, 0xfa, 0x87, 0xfb // sxtab al r11 r5 r7
};
const byte kInstruction_sxtab_al_r7_r4_r14[] = {
  0x44, 0xfa, 0x8e, 0xf7 // sxtab al r7 r4 r14
};
const byte kInstruction_sxtab_al_r14_r5_r10[] = {
  0x45, 0xfa, 0x8a, 0xfe // sxtab al r14 r5 r10
};
const byte kInstruction_sxtab_al_r11_r9_r0[] = {
  0x49, 0xfa, 0x80, 0xfb // sxtab al r11 r9 r0
};
const byte kInstruction_sxtab_al_r9_r8_r4[] = {
  0x48, 0xfa, 0x84, 0xf9 // sxtab al r9 r8 r4
};
const byte kInstruction_sxtab_al_r9_r0_r3[] = {
  0x40, 0xfa, 0x83, 0xf9 // sxtab al r9 r0 r3
};
const byte kInstruction_sxtab_al_r11_r4_r4[] = {
  0x44, 0xfa, 0x84, 0xfb // sxtab al r11 r4 r4
};
const byte kInstruction_sxtab_al_r2_r5_r7[] = {
  0x45, 0xfa, 0x87, 0xf2 // sxtab al r2 r5 r7
};
const byte kInstruction_sxtab_al_r14_r1_r8[] = {
  0x41, 0xfa, 0x88, 0xfe // sxtab al r14 r1 r8
};
const byte kInstruction_sxtab_al_r12_r11_r10[] = {
  0x4b, 0xfa, 0x8a, 0xfc // sxtab al r12 r11 r10
};
const byte kInstruction_sxtab_al_r6_r7_r14[] = {
  0x47, 0xfa, 0x8e, 0xf6 // sxtab al r6 r7 r14
};
const byte kInstruction_sxtab_al_r6_r13_r12[] = {
  0x4d, 0xfa, 0x8c, 0xf6 // sxtab al r6 r13 r12
};
const byte kInstruction_sxtab_al_r11_r11_r13[] = {
  0x4b, 0xfa, 0x8d, 0xfb // sxtab al r11 r11 r13
};
const TestResult kReferencesxtab[] = {
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r9_r11),
    kInstruction_sxtab_al_r12_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r4_r10),
    kInstruction_sxtab_al_r3_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r0_r12),
    kInstruction_sxtab_al_r2_r0_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r9_r13),
    kInstruction_sxtab_al_r9_r9_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r2_r4),
    kInstruction_sxtab_al_r11_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r3_r7),
    kInstruction_sxtab_al_r7_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r6_r9),
    kInstruction_sxtab_al_r11_r6_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r7_r11),
    kInstruction_sxtab_al_r8_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r12_r14),
    kInstruction_sxtab_al_r14_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r5_r8),
    kInstruction_sxtab_al_r8_r5_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r4_r2),
    kInstruction_sxtab_al_r4_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r6_r7),
    kInstruction_sxtab_al_r10_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r13_r7),
    kInstruction_sxtab_al_r9_r13_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r8_r5),
    kInstruction_sxtab_al_r6_r8_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r10_r6),
    kInstruction_sxtab_al_r5_r10_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r7_r11),
    kInstruction_sxtab_al_r14_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r4_r14),
    kInstruction_sxtab_al_r11_r4_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r6_r4),
    kInstruction_sxtab_al_r5_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r9_r0),
    kInstruction_sxtab_al_r4_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r0_r8),
    kInstruction_sxtab_al_r5_r0_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r2_r10),
    kInstruction_sxtab_al_r6_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r11_r14),
    kInstruction_sxtab_al_r0_r11_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r10_r1),
    kInstruction_sxtab_al_r3_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r7_r8),
    kInstruction_sxtab_al_r13_r7_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r5_r2),
    kInstruction_sxtab_al_r12_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r14_r7),
    kInstruction_sxtab_al_r7_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r6_r10),
    kInstruction_sxtab_al_r6_r6_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r0_r2),
    kInstruction_sxtab_al_r2_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r14_r11),
    kInstruction_sxtab_al_r8_r14_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r14_r2),
    kInstruction_sxtab_al_r10_r14_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r11_r6),
    kInstruction_sxtab_al_r14_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r2_r11),
    kInstruction_sxtab_al_r9_r2_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r9_r10),
    kInstruction_sxtab_al_r9_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r9_r13),
    kInstruction_sxtab_al_r11_r9_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r12_r7),
    kInstruction_sxtab_al_r14_r12_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r7),
    kInstruction_sxtab_al_r9_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r7_r8),
    kInstruction_sxtab_al_r0_r7_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r4_r4),
    kInstruction_sxtab_al_r12_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r9_r7),
    kInstruction_sxtab_al_r7_r9_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r13_r13),
    kInstruction_sxtab_al_r1_r13_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r11_r11),
    kInstruction_sxtab_al_r13_r11_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r0_r7),
    kInstruction_sxtab_al_r0_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r12_r1),
    kInstruction_sxtab_al_r2_r12_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r2_r5),
    kInstruction_sxtab_al_r8_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r0_r1),
    kInstruction_sxtab_al_r6_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r13_r0),
    kInstruction_sxtab_al_r9_r13_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r5_r1),
    kInstruction_sxtab_al_r12_r5_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r4),
    kInstruction_sxtab_al_r14_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r9_r2),
    kInstruction_sxtab_al_r5_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r10),
    kInstruction_sxtab_al_r8_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r11_r12),
    kInstruction_sxtab_al_r0_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r8_r4),
    kInstruction_sxtab_al_r2_r8_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r6_r9),
    kInstruction_sxtab_al_r13_r6_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r12_r9),
    kInstruction_sxtab_al_r2_r12_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r0_r3),
    kInstruction_sxtab_al_r12_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r1_r1),
    kInstruction_sxtab_al_r13_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r6_r7),
    kInstruction_sxtab_al_r14_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r6_r6),
    kInstruction_sxtab_al_r8_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r9_r11),
    kInstruction_sxtab_al_r14_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r3_r3),
    kInstruction_sxtab_al_r6_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r8_r14),
    kInstruction_sxtab_al_r6_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r3_r6),
    kInstruction_sxtab_al_r8_r3_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r6_r11),
    kInstruction_sxtab_al_r12_r6_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r8_r14),
    kInstruction_sxtab_al_r5_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r10_r8),
    kInstruction_sxtab_al_r4_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r12_r14),
    kInstruction_sxtab_al_r4_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r8_r10),
    kInstruction_sxtab_al_r14_r8_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r10_r8),
    kInstruction_sxtab_al_r2_r10_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r14_r7),
    kInstruction_sxtab_al_r0_r14_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r13_r9),
    kInstruction_sxtab_al_r9_r13_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r0_r14),
    kInstruction_sxtab_al_r7_r0_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r4_r9),
    kInstruction_sxtab_al_r14_r4_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r1_r11),
    kInstruction_sxtab_al_r1_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r6_r1),
    kInstruction_sxtab_al_r11_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r8_r2),
    kInstruction_sxtab_al_r2_r8_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r4),
    kInstruction_sxtab_al_r1_r8_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r3_r3),
    kInstruction_sxtab_al_r2_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r8_r8),
    kInstruction_sxtab_al_r4_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r4_r1),
    kInstruction_sxtab_al_r6_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r10_r3),
    kInstruction_sxtab_al_r1_r10_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r14_r8),
    kInstruction_sxtab_al_r11_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r6_r3),
    kInstruction_sxtab_al_r1_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r13_r10),
    kInstruction_sxtab_al_r3_r13_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r13_r8),
    kInstruction_sxtab_al_r6_r13_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r3_r13),
    kInstruction_sxtab_al_r12_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r2_r4),
    kInstruction_sxtab_al_r8_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r1_r7),
    kInstruction_sxtab_al_r10_r1_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r7_r12),
    kInstruction_sxtab_al_r11_r7_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r4_r7),
    kInstruction_sxtab_al_r4_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r7_r9),
    kInstruction_sxtab_al_r1_r7_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r0),
    kInstruction_sxtab_al_r14_r3_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r4_r7),
    kInstruction_sxtab_al_r10_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r9_r11),
    kInstruction_sxtab_al_r4_r9_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r2_r0),
    kInstruction_sxtab_al_r2_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r6_r12),
    kInstruction_sxtab_al_r1_r6_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r5_r6),
    kInstruction_sxtab_al_r0_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r11_r10),
    kInstruction_sxtab_al_r8_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r4_r3),
    kInstruction_sxtab_al_r10_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r0_r3),
    kInstruction_sxtab_al_r1_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r8_r6),
    kInstruction_sxtab_al_r11_r8_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r0),
    kInstruction_sxtab_al_r8_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r8_r7),
    kInstruction_sxtab_al_r5_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r1),
    kInstruction_sxtab_al_r9_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r11_r12),
    kInstruction_sxtab_al_r1_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r5_r11),
    kInstruction_sxtab_al_r5_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r6_r13),
    kInstruction_sxtab_al_r4_r6_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r1_r11),
    kInstruction_sxtab_al_r14_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r0_r12),
    kInstruction_sxtab_al_r11_r0_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r2_r0),
    kInstruction_sxtab_al_r9_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r5_r10),
    kInstruction_sxtab_al_r11_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r11_r2),
    kInstruction_sxtab_al_r1_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r2_r9),
    kInstruction_sxtab_al_r14_r2_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r10_r3),
    kInstruction_sxtab_al_r4_r10_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r5_r11),
    kInstruction_sxtab_al_r1_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r10_r4),
    kInstruction_sxtab_al_r3_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r7_r10),
    kInstruction_sxtab_al_r1_r7_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r8_r14),
    kInstruction_sxtab_al_r14_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r11_r4),
    kInstruction_sxtab_al_r12_r11_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r9_r6),
    kInstruction_sxtab_al_r7_r9_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r8_r9),
    kInstruction_sxtab_al_r8_r8_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r5_r0),
    kInstruction_sxtab_al_r12_r5_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r11_r12),
    kInstruction_sxtab_al_r6_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r5_r11),
    kInstruction_sxtab_al_r9_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r14_r6),
    kInstruction_sxtab_al_r6_r14_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r3_r7),
    kInstruction_sxtab_al_r0_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r5_r10),
    kInstruction_sxtab_al_r9_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r1_r6),
    kInstruction_sxtab_al_r4_r1_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r1_r13),
    kInstruction_sxtab_al_r6_r1_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r1_r4),
    kInstruction_sxtab_al_r13_r1_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r11_r9),
    kInstruction_sxtab_al_r10_r11_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r13_r7),
    kInstruction_sxtab_al_r14_r13_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r3_r13),
    kInstruction_sxtab_al_r5_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r6),
    kInstruction_sxtab_al_r8_r9_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r10_r5),
    kInstruction_sxtab_al_r9_r10_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r11_r7),
    kInstruction_sxtab_al_r12_r11_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r13_r12),
    kInstruction_sxtab_al_r5_r13_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r13_r8),
    kInstruction_sxtab_al_r9_r13_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r3_r9),
    kInstruction_sxtab_al_r5_r3_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r5_r14),
    kInstruction_sxtab_al_r8_r5_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r10_r10),
    kInstruction_sxtab_al_r8_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r6_r4),
    kInstruction_sxtab_al_r2_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r7_r1),
    kInstruction_sxtab_al_r10_r7_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r0_r5),
    kInstruction_sxtab_al_r4_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r12_r9),
    kInstruction_sxtab_al_r7_r12_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r11_r10),
    kInstruction_sxtab_al_r11_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r9_r13),
    kInstruction_sxtab_al_r3_r9_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r4_r4),
    kInstruction_sxtab_al_r10_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r1_r11),
    kInstruction_sxtab_al_r13_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r13_r0),
    kInstruction_sxtab_al_r2_r13_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r4_r1),
    kInstruction_sxtab_al_r11_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r3_r10),
    kInstruction_sxtab_al_r1_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r13_r2),
    kInstruction_sxtab_al_r4_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r8_r0),
    kInstruction_sxtab_al_r4_r8_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r6_r1),
    kInstruction_sxtab_al_r9_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r14_r10),
    kInstruction_sxtab_al_r14_r14_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r9_r2),
    kInstruction_sxtab_al_r9_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r12),
    kInstruction_sxtab_al_r14_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r0),
    kInstruction_sxtab_al_r9_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r10_r11),
    kInstruction_sxtab_al_r10_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r1_r13),
    kInstruction_sxtab_al_r0_r1_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r8_r13),
    kInstruction_sxtab_al_r10_r8_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r0_r2),
    kInstruction_sxtab_al_r8_r0_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r0_r7),
    kInstruction_sxtab_al_r2_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r12_r10),
    kInstruction_sxtab_al_r11_r12_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r5_r3),
    kInstruction_sxtab_al_r0_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r2_r0),
    kInstruction_sxtab_al_r3_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r10_r1),
    kInstruction_sxtab_al_r12_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r2_r14),
    kInstruction_sxtab_al_r3_r2_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r12_r1),
    kInstruction_sxtab_al_r4_r12_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r8_r3),
    kInstruction_sxtab_al_r14_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r14_r12),
    kInstruction_sxtab_al_r4_r14_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r3_r4),
    kInstruction_sxtab_al_r3_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r13_r4),
    kInstruction_sxtab_al_r10_r13_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r2_r12),
    kInstruction_sxtab_al_r9_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r13_r7),
    kInstruction_sxtab_al_r5_r13_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r12_r9),
    kInstruction_sxtab_al_r13_r12_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r4_r5),
    kInstruction_sxtab_al_r4_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r12),
    kInstruction_sxtab_al_r1_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r6),
    kInstruction_sxtab_al_r1_r8_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r11_r4),
    kInstruction_sxtab_al_r14_r11_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r9_r3),
    kInstruction_sxtab_al_r14_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r5_r9),
    kInstruction_sxtab_al_r11_r5_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r10_r10),
    kInstruction_sxtab_al_r3_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r13_r14),
    kInstruction_sxtab_al_r6_r13_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r14),
    kInstruction_sxtab_al_r1_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r1_r10),
    kInstruction_sxtab_al_r10_r1_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r1_r1),
    kInstruction_sxtab_al_r8_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r10_r4),
    kInstruction_sxtab_al_r10_r10_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r11_r13),
    kInstruction_sxtab_al_r9_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r8_r8),
    kInstruction_sxtab_al_r14_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r4_r10),
    kInstruction_sxtab_al_r13_r4_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r1),
    kInstruction_sxtab_al_r14_r3_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r11_r14),
    kInstruction_sxtab_al_r5_r11_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r6_r6),
    kInstruction_sxtab_al_r2_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r1_r14),
    kInstruction_sxtab_al_r14_r1_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r10_r0),
    kInstruction_sxtab_al_r5_r10_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r2_r5),
    kInstruction_sxtab_al_r11_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r9_r1),
    kInstruction_sxtab_al_r4_r9_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r7_r2),
    kInstruction_sxtab_al_r12_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r12_r9),
    kInstruction_sxtab_al_r10_r12_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r3_r12),
    kInstruction_sxtab_al_r2_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r6_r3),
    kInstruction_sxtab_al_r7_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r11_r8),
    kInstruction_sxtab_al_r11_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r14_r10),
    kInstruction_sxtab_al_r6_r14_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r2_r4),
    kInstruction_sxtab_al_r13_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r5_r4),
    kInstruction_sxtab_al_r5_r5_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r1_r2),
    kInstruction_sxtab_al_r9_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r10_r14),
    kInstruction_sxtab_al_r3_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r9_r0),
    kInstruction_sxtab_al_r1_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r10_r12),
    kInstruction_sxtab_al_r4_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r2),
    kInstruction_sxtab_al_r8_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r14_r0),
    kInstruction_sxtab_al_r0_r14_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r11_r11),
    kInstruction_sxtab_al_r14_r11_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r12_r5),
    kInstruction_sxtab_al_r9_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r8_r3),
    kInstruction_sxtab_al_r11_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r11_r8),
    kInstruction_sxtab_al_r13_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r13_r12),
    kInstruction_sxtab_al_r4_r13_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r13_r6),
    kInstruction_sxtab_al_r10_r13_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r7_r13),
    kInstruction_sxtab_al_r14_r7_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r2_r12),
    kInstruction_sxtab_al_r10_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r9_r4),
    kInstruction_sxtab_al_r6_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r8_r2),
    kInstruction_sxtab_al_r9_r8_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r5_r5),
    kInstruction_sxtab_al_r14_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r14_r4),
    kInstruction_sxtab_al_r11_r14_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r0_r12),
    kInstruction_sxtab_al_r8_r0_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r6_r5),
    kInstruction_sxtab_al_r11_r6_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r13_r9),
    kInstruction_sxtab_al_r11_r13_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r2_r0),
    kInstruction_sxtab_al_r14_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r7_r10),
    kInstruction_sxtab_al_r7_r7_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r12_r2),
    kInstruction_sxtab_al_r10_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r10_r9),
    kInstruction_sxtab_al_r9_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r0_r9),
    kInstruction_sxtab_al_r11_r0_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r5_r7),
    kInstruction_sxtab_al_r3_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r8_r0),
    kInstruction_sxtab_al_r0_r8_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r11_r4),
    kInstruction_sxtab_al_r1_r11_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r14_r3),
    kInstruction_sxtab_al_r1_r14_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r12_r13),
    kInstruction_sxtab_al_r12_r12_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r13_r1),
    kInstruction_sxtab_al_r14_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r7_r4),
    kInstruction_sxtab_al_r8_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r12_r7),
    kInstruction_sxtab_al_r13_r12_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r12_r14),
    kInstruction_sxtab_al_r5_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r2_r14),
    kInstruction_sxtab_al_r2_r2_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r5_r9),
    kInstruction_sxtab_al_r6_r5_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r1_r3),
    kInstruction_sxtab_al_r8_r1_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r10_r1),
    kInstruction_sxtab_al_r9_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r6_r7),
    kInstruction_sxtab_al_r0_r6_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r9_r1),
    kInstruction_sxtab_al_r13_r9_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r4_r8),
    kInstruction_sxtab_al_r11_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r1_r5),
    kInstruction_sxtab_al_r10_r1_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r4_r6),
    kInstruction_sxtab_al_r7_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r13),
    kInstruction_sxtab_al_r14_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r0_r1),
    kInstruction_sxtab_al_r9_r0_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r10_r10),
    kInstruction_sxtab_al_r6_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r8_r8),
    kInstruction_sxtab_al_r13_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r1_r2),
    kInstruction_sxtab_al_r1_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r1_r9),
    kInstruction_sxtab_al_r8_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r7_r5),
    kInstruction_sxtab_al_r4_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r13_r1),
    kInstruction_sxtab_al_r2_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r9_r5),
    kInstruction_sxtab_al_r9_r9_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r12_r8),
    kInstruction_sxtab_al_r11_r12_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r0_r3),
    kInstruction_sxtab_al_r7_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r4_r13),
    kInstruction_sxtab_al_r3_r4_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r7_r9),
    kInstruction_sxtab_al_r7_r7_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r9_r5),
    kInstruction_sxtab_al_r2_r9_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r2_r0),
    kInstruction_sxtab_al_r13_r2_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r4_r2),
    kInstruction_sxtab_al_r8_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r11_r11),
    kInstruction_sxtab_al_r7_r11_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r1_r2),
    kInstruction_sxtab_al_r6_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r5_r7),
    kInstruction_sxtab_al_r10_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r14_r2),
    kInstruction_sxtab_al_r8_r14_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r13_r5),
    kInstruction_sxtab_al_r12_r13_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r4_r8),
    kInstruction_sxtab_al_r0_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r11_r12),
    kInstruction_sxtab_al_r9_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r10_r5),
    kInstruction_sxtab_al_r6_r10_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r10_r1),
    kInstruction_sxtab_al_r8_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r12_r4),
    kInstruction_sxtab_al_r13_r12_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r2_r11),
    kInstruction_sxtab_al_r14_r2_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r10_r7),
    kInstruction_sxtab_al_r1_r10_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r1_r9),
    kInstruction_sxtab_al_r0_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r12_r11),
    kInstruction_sxtab_al_r0_r12_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r5_r13),
    kInstruction_sxtab_al_r0_r5_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r8_r12),
    kInstruction_sxtab_al_r9_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r3_r14),
    kInstruction_sxtab_al_r13_r3_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r2_r10),
    kInstruction_sxtab_al_r5_r2_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r9_r3),
    kInstruction_sxtab_al_r5_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r1_r8),
    kInstruction_sxtab_al_r10_r1_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r1_r9),
    kInstruction_sxtab_al_r14_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r13_r2),
    kInstruction_sxtab_al_r7_r13_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r7_r8),
    kInstruction_sxtab_al_r9_r7_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r7_r13),
    kInstruction_sxtab_al_r4_r7_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r9_r12),
    kInstruction_sxtab_al_r6_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r2_r8),
    kInstruction_sxtab_al_r14_r2_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r9_r8),
    kInstruction_sxtab_al_r12_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r5_r8),
    kInstruction_sxtab_al_r13_r5_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r11_r3),
    kInstruction_sxtab_al_r13_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r1_r9),
    kInstruction_sxtab_al_r4_r1_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r11_r13),
    kInstruction_sxtab_al_r10_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r13_r5),
    kInstruction_sxtab_al_r11_r13_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r3_r13),
    kInstruction_sxtab_al_r4_r3_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r6_r3),
    kInstruction_sxtab_al_r12_r6_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r5_r3),
    kInstruction_sxtab_al_r12_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r7_r2),
    kInstruction_sxtab_al_r3_r7_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r9_r10),
    kInstruction_sxtab_al_r6_r9_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r2_r1),
    kInstruction_sxtab_al_r6_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r13_r1),
    kInstruction_sxtab_al_r13_r13_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r10_r12),
    kInstruction_sxtab_al_r10_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r5_r3),
    kInstruction_sxtab_al_r5_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r10_r14),
    kInstruction_sxtab_al_r8_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r12_r6),
    kInstruction_sxtab_al_r4_r12_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r12_r5),
    kInstruction_sxtab_al_r1_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r1_r12),
    kInstruction_sxtab_al_r14_r1_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r3_r10),
    kInstruction_sxtab_al_r5_r3_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r11_r8),
    kInstruction_sxtab_al_r6_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r5_r7),
    kInstruction_sxtab_al_r1_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r14_r8),
    kInstruction_sxtab_al_r7_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r10_r11),
    kInstruction_sxtab_al_r7_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r14_r11),
    kInstruction_sxtab_al_r0_r14_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r12_r5),
    kInstruction_sxtab_al_r0_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r2_r3),
    kInstruction_sxtab_al_r2_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r4_r7),
    kInstruction_sxtab_al_r1_r4_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r10_r1),
    kInstruction_sxtab_al_r10_r10_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r6_r10),
    kInstruction_sxtab_al_r7_r6_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r14_r9),
    kInstruction_sxtab_al_r10_r14_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r14_r14),
    kInstruction_sxtab_al_r11_r14_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r13_r6),
    kInstruction_sxtab_al_r9_r13_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r8_r13),
    kInstruction_sxtab_al_r3_r8_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r6_r8),
    kInstruction_sxtab_al_r14_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r4_r4),
    kInstruction_sxtab_al_r14_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r5_r3),
    kInstruction_sxtab_al_r9_r5_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r4_r14),
    kInstruction_sxtab_al_r2_r4_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r2_r12),
    kInstruction_sxtab_al_r14_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r6_r2),
    kInstruction_sxtab_al_r11_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r9_r12),
    kInstruction_sxtab_al_r0_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r1_r14),
    kInstruction_sxtab_al_r3_r1_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r14_r1),
    kInstruction_sxtab_al_r10_r14_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r7_r13),
    kInstruction_sxtab_al_r2_r7_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r2_r13),
    kInstruction_sxtab_al_r11_r2_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r11_r12),
    kInstruction_sxtab_al_r4_r11_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r12_r0),
    kInstruction_sxtab_al_r14_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r9_r8),
    kInstruction_sxtab_al_r6_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r10_r11),
    kInstruction_sxtab_al_r4_r10_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r2_r2),
    kInstruction_sxtab_al_r1_r2_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r5),
    kInstruction_sxtab_al_r1_r8_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r13_r6),
    kInstruction_sxtab_al_r14_r13_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r12_r10),
    kInstruction_sxtab_al_r5_r12_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r0_r9),
    kInstruction_sxtab_al_r14_r0_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r6_r6),
    kInstruction_sxtab_al_r4_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r7_r11),
    kInstruction_sxtab_al_r3_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r9_r2),
    kInstruction_sxtab_al_r12_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r1_r1),
    kInstruction_sxtab_al_r1_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r5_r14),
    kInstruction_sxtab_al_r11_r5_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r6),
    kInstruction_sxtab_al_r9_r4_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r11_r2),
    kInstruction_sxtab_al_r10_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r6_r2),
    kInstruction_sxtab_al_r14_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r3),
    kInstruction_sxtab_al_r9_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r3_r8),
    kInstruction_sxtab_al_r3_r3_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r10_r10),
    kInstruction_sxtab_al_r14_r10_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r11_r6),
    kInstruction_sxtab_al_r2_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r12_r0),
    kInstruction_sxtab_al_r8_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r1_r13),
    kInstruction_sxtab_al_r8_r1_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r8_r3),
    kInstruction_sxtab_al_r10_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r12_r8),
    kInstruction_sxtab_al_r12_r12_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r2_r11),
    kInstruction_sxtab_al_r2_r2_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r5_r5),
    kInstruction_sxtab_al_r8_r5_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r14_r8),
    kInstruction_sxtab_al_r3_r14_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r10_r14),
    kInstruction_sxtab_al_r13_r10_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r6_r8),
    kInstruction_sxtab_al_r12_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r2_r5),
    kInstruction_sxtab_al_r6_r2_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r8_r14),
    kInstruction_sxtab_al_r12_r8_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r6_r2),
    kInstruction_sxtab_al_r10_r6_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r4_r1),
    kInstruction_sxtab_al_r2_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r0_r12),
    kInstruction_sxtab_al_r4_r0_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r7_r4),
    kInstruction_sxtab_al_r13_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r11_r7),
    kInstruction_sxtab_al_r14_r11_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r4_r0),
    kInstruction_sxtab_al_r4_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r10_r2),
    kInstruction_sxtab_al_r1_r10_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r4_r8),
    kInstruction_sxtab_al_r2_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r2_r12),
    kInstruction_sxtab_al_r2_r2_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r4_r5),
    kInstruction_sxtab_al_r2_r4_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r3_r12),
    kInstruction_sxtab_al_r9_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r7_r4),
    kInstruction_sxtab_al_r1_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r7_r12),
    kInstruction_sxtab_al_r13_r7_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r14_r0),
    kInstruction_sxtab_al_r12_r14_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r12_r14),
    kInstruction_sxtab_al_r13_r12_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r6_r0),
    kInstruction_sxtab_al_r9_r6_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r12_r4),
    kInstruction_sxtab_al_r1_r12_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r8_r12),
    kInstruction_sxtab_al_r5_r8_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r11_r9),
    kInstruction_sxtab_al_r13_r11_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r2_r7),
    kInstruction_sxtab_al_r0_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r3_r7),
    kInstruction_sxtab_al_r5_r3_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r3_r12),
    kInstruction_sxtab_al_r0_r3_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r9_r4),
    kInstruction_sxtab_al_r14_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r9_r0),
    kInstruction_sxtab_al_r14_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r8_r0),
    kInstruction_sxtab_al_r3_r8_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r5_r8),
    kInstruction_sxtab_al_r3_r5_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r1_r8),
    kInstruction_sxtab_al_r3_r1_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r2_r8),
    kInstruction_sxtab_al_r9_r2_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r13_r8),
    kInstruction_sxtab_al_r3_r13_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r2_r4),
    kInstruction_sxtab_al_r10_r2_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r5_r9),
    kInstruction_sxtab_al_r1_r5_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r12_r3),
    kInstruction_sxtab_al_r8_r12_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r14_r2),
    kInstruction_sxtab_al_r7_r14_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r7_r4),
    kInstruction_sxtab_al_r14_r7_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r0_r6),
    kInstruction_sxtab_al_r6_r0_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r3_r9),
    kInstruction_sxtab_al_r10_r3_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r9_r12),
    kInstruction_sxtab_al_r7_r9_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r3_r4),
    kInstruction_sxtab_al_r2_r3_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r4_r3),
    kInstruction_sxtab_al_r12_r4_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r11_r2),
    kInstruction_sxtab_al_r13_r11_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r7_r5),
    kInstruction_sxtab_al_r12_r7_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r1_r1),
    kInstruction_sxtab_al_r12_r1_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r5_r13),
    kInstruction_sxtab_al_r9_r5_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r8_r3),
    kInstruction_sxtab_al_r6_r8_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r0_r10),
    kInstruction_sxtab_al_r10_r0_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r3_r5),
    kInstruction_sxtab_al_r4_r3_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r2_r1),
    kInstruction_sxtab_al_r10_r2_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r11_r13),
    kInstruction_sxtab_al_r0_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r0_r5),
    kInstruction_sxtab_al_r1_r0_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r10_r0),
    kInstruction_sxtab_al_r10_r10_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r8),
    kInstruction_sxtab_al_r8_r9_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r9_r3),
    kInstruction_sxtab_al_r4_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r14),
    kInstruction_sxtab_al_r9_r4_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r14_r3),
    kInstruction_sxtab_al_r4_r14_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r8_r2),
    kInstruction_sxtab_al_r5_r8_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r11_r3),
    kInstruction_sxtab_al_r10_r11_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r8_r1),
    kInstruction_sxtab_al_r6_r8_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r3),
    kInstruction_sxtab_al_r8_r9_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r6_r13),
    kInstruction_sxtab_al_r6_r6_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r10_r0),
    kInstruction_sxtab_al_r7_r10_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r14_r14),
    kInstruction_sxtab_al_r6_r14_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r4_r2),
    kInstruction_sxtab_al_r7_r4_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r7_r0),
    kInstruction_sxtab_al_r0_r7_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r7_r11),
    kInstruction_sxtab_al_r10_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r8_r8),
    kInstruction_sxtab_al_r1_r8_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r4_r8),
    kInstruction_sxtab_al_r9_r4_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r5_r2),
    kInstruction_sxtab_al_r14_r5_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r12_r2),
    kInstruction_sxtab_al_r6_r12_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r11_r8),
    kInstruction_sxtab_al_r1_r11_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r5_r14),
    kInstruction_sxtab_al_r6_r5_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r1_r2),
    kInstruction_sxtab_al_r12_r1_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r3_r3),
    kInstruction_sxtab_al_r8_r3_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r8_r7),
    kInstruction_sxtab_al_r13_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r11_r13),
    kInstruction_sxtab_al_r14_r11_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r14_r14),
    kInstruction_sxtab_al_r1_r14_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r4_r0),
    kInstruction_sxtab_al_r12_r4_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r2_r3),
    kInstruction_sxtab_al_r0_r2_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r5_r6),
    kInstruction_sxtab_al_r1_r5_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r6_r4),
    kInstruction_sxtab_al_r7_r6_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r9_r2),
    kInstruction_sxtab_al_r0_r9_r2,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r3_r14),
    kInstruction_sxtab_al_r7_r3_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r5_r11),
    kInstruction_sxtab_al_r0_r5_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r12_r5),
    kInstruction_sxtab_al_r12_r12_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r11_r6),
    kInstruction_sxtab_al_r12_r11_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r6_r8),
    kInstruction_sxtab_al_r2_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r10_r9),
    kInstruction_sxtab_al_r6_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r11_r1),
    kInstruction_sxtab_al_r2_r11_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r2_r7),
    kInstruction_sxtab_al_r11_r2_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r14_r13),
    kInstruction_sxtab_al_r7_r14_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r5_r10),
    kInstruction_sxtab_al_r10_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r6_r1),
    kInstruction_sxtab_al_r5_r6_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r4_r1),
    kInstruction_sxtab_al_r7_r4_r1,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r12_r0),
    kInstruction_sxtab_al_r7_r12_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r6_r8),
    kInstruction_sxtab_al_r3_r6_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r0_r8),
    kInstruction_sxtab_al_r0_r0_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r1_r11),
    kInstruction_sxtab_al_r12_r1_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r3_r14),
    kInstruction_sxtab_al_r14_r3_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r0_r14),
    kInstruction_sxtab_al_r12_r0_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r10_r9),
    kInstruction_sxtab_al_r5_r10_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r7_r12),
    kInstruction_sxtab_al_r3_r7_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r8_r7),
    kInstruction_sxtab_al_r10_r8_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r14_r4),
    kInstruction_sxtab_al_r8_r14_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r7_r7),
    kInstruction_sxtab_al_r6_r7_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r2_r14),
    kInstruction_sxtab_al_r13_r2_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r1_r11_r11),
    kInstruction_sxtab_al_r1_r11_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r0_r13),
    kInstruction_sxtab_al_r5_r0_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r6_r11),
    kInstruction_sxtab_al_r7_r6_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r4_r1_r14),
    kInstruction_sxtab_al_r4_r1_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r4_r9),
    kInstruction_sxtab_al_r10_r4_r9,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r5_r6_r6),
    kInstruction_sxtab_al_r5_r6_r6,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r8_r13),
    kInstruction_sxtab_al_r14_r8_r13,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r13_r1_r12),
    kInstruction_sxtab_al_r13_r1_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r7_r11),
    kInstruction_sxtab_al_r2_r7_r11,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r10_r4_r12),
    kInstruction_sxtab_al_r10_r4_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r3_r10_r12),
    kInstruction_sxtab_al_r3_r10_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r0_r9_r5),
    kInstruction_sxtab_al_r0_r9_r5,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r8_r9_r4),
    kInstruction_sxtab_al_r8_r9_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r0_r7),
    kInstruction_sxtab_al_r11_r0_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r5_r7),
    kInstruction_sxtab_al_r11_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r7_r4_r14),
    kInstruction_sxtab_al_r7_r4_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r5_r10),
    kInstruction_sxtab_al_r14_r5_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r9_r0),
    kInstruction_sxtab_al_r11_r9_r0,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r8_r4),
    kInstruction_sxtab_al_r9_r8_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r9_r0_r3),
    kInstruction_sxtab_al_r9_r0_r3,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r4_r4),
    kInstruction_sxtab_al_r11_r4_r4,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r2_r5_r7),
    kInstruction_sxtab_al_r2_r5_r7,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r14_r1_r8),
    kInstruction_sxtab_al_r14_r1_r8,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r12_r11_r10),
    kInstruction_sxtab_al_r12_r11_r10,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r7_r14),
    kInstruction_sxtab_al_r6_r7_r14,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r6_r13_r12),
    kInstruction_sxtab_al_r6_r13_r12,
  },
  {
    ARRAY_SIZE(kInstruction_sxtab_al_r11_r11_r13),
    kInstruction_sxtab_al_r11_r11_r13,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_RM_SXTAB_T32_H_
